@@ -32,7 +32,6 @@
 #include "expert.h"
 #include "config.h"
 
-
 const int messageTimeout = 5000; //!< status bar message timeout in millisec.
 
 #if defined(Q_OS_MACX)
@@ -46,6 +45,34 @@ QCString getResourcePath()
   result+="/Contents/Resources/";
   return result;
 }
+
+#define GRAPHVIZ_PATH    "/Applications/Graphviz.app"
+#define DOT_PATH         GRAPHVIZ_PATH "/Contents/MacOS"
+#define DOT_LOCATION     DOT_PATH "/dot"
+
+bool checkIfDotInstalled()
+{
+  QFileInfo fi(GRAPHVIZ_PATH);
+  if (fi.exists() && fi.isDir())
+  {
+    fi.setFile(DOT_LOCATION);
+    if (fi.exists() && fi.isFile())
+    {
+      return TRUE;
+    }
+  }
+  return FALSE;
+}
+
+void setDotPath()
+{
+  if (checkIfDotInstalled())
+  {
+    Config_getString("DOT_PATH")=DOT_PATH;
+    Config_getBool("HAVE_DOT")=TRUE;
+  }
+}
+
 #endif
 
 
@@ -651,10 +678,7 @@ MainWidget::MainWidget(QWidget *parent)
   Config::instance()->init();
   Config::instance()->check();
 #if defined(Q_OS_MACX)
-  // we bundle dot with doxywizard on the Mac so we can safely enable
-  // it here
-  Config_getString("DOT_PATH")=getResourcePath();
-  Config_getBool("HAVE_DOT")=TRUE;
+  setDotPath();
 #endif
   
   QWidget *w = new QWidget(this);
@@ -799,12 +823,12 @@ MainWidget::MainWidget(QWidget *parent)
   // load default settings
   m_settings.setPath("www.doxygen.org","Doxygen GUI");
   bool ok;
-  QString config = m_settings.readEntry("/config/default",QString::null,&ok);
+  QString config = m_settings.readEntry("/doxywizard/config/default",QString::null,&ok);
   if (ok && !config.isEmpty())
   {
     Config::instance()->parseString("default settings",config);
   }
-  QString workingDir = m_settings.readEntry("/config/workingdir",QString::null,&ok);
+  QString workingDir = m_settings.readEntry("/doxywizard/config/workingdir",QString::null,&ok);
   if (ok && !workingDir.isEmpty())
   {
     m_workingDir->setText(workingDir);
@@ -812,7 +836,7 @@ MainWidget::MainWidget(QWidget *parent)
   setConfigSaved(FALSE);
   for (int i=0;i<10;i++)
   {
-    QString entry = m_settings.readEntry(QString().sprintf("/recent/config%d",i));
+    QString entry = m_settings.readEntry(QString().sprintf("/doxywizard/recent/config%d",i));
     if (!entry.isEmpty())
     {
       addRecentFile(entry);
@@ -1079,7 +1103,10 @@ void MainWidget::launchWizard()
         break;
     }
 #if defined(Q_OS_MACX)
-    Config_getString("DOT_PATH")=getResourcePath();
+    if (Config_getBool("HAVE_DOT"))
+    {
+      setDotPath();
+    }
 #endif
     setConfigSaved(FALSE);
   }
@@ -1098,9 +1125,11 @@ void MainWidget::loadConfigFromFile(const QString &fn)
   {
     Config::instance()->convertStrToVal();
 #if defined(Q_OS_MACX)
-    if (Config_getString("DOT_PATH")!=getResourcePath())
+    if (checkIfDotInstalled() && 
+        qstricmp(Config_getString("DOT_PATH"),DOT_PATH)!=0
+       )
     {
-      Config_getString("DOT_PATH")=getResourcePath();
+      Config_getString("DOT_PATH")=DOT_PATH;
       setConfigSaved(FALSE);
     }
     else
@@ -1134,12 +1163,9 @@ void MainWidget::launchExpert()
   expert.init();
   expert.exec();
 #if defined(Q_OS_MACX)
-  // we bundle dot with doxywizard on the Mac so we can safely enable
-  // it here
-  Config_getString("DOT_PATH")=getResourcePath();
-  Config_getBool("HAVE_DOT")=TRUE;
+  setDotPath();
 #endif
-  setConfigSaved(FALSE);
+  if (expert.hasChanged()) setConfigSaved(FALSE);
 }
 
 void MainWidget::saveDefaults()
@@ -1152,8 +1178,8 @@ void MainWidget::saveDefaults()
     QString newConfig;
     QTextStream t(&newConfig,IO_WriteOnly);
     Config::instance()->writeTemplate(t,TRUE,FALSE);
-    m_settings.writeEntry("/config/default",newConfig);
-    m_settings.writeEntry("/config/workingdir",m_workingDir->text());
+    m_settings.writeEntry("/doxywizard/config/default",newConfig);
+    m_settings.writeEntry("/doxywizard/config/workingdir",m_workingDir->text());
     statusBar()->message("Current configuration saved as default",messageTimeout);
   }
 }
@@ -1191,10 +1217,7 @@ void MainWidget::resetConfig()
     // initialize config settings
     Config::instance()->init();
 #if defined(Q_OS_MACX)
-    // we bundle dot with doxywizard on the Mac so we can safely enable
-    // it here
-    Config_getString("DOT_PATH")=getResourcePath();
-    Config_getBool("HAVE_DOT")=TRUE;
+    setDotPath();
 #endif
 
     m_configFileName = "";
@@ -1338,7 +1361,7 @@ void MainWidget::addRecentFile(const QString &file)
   for ( it = m_recentFiles.begin(); it != m_recentFiles.end(); ++it, ++i )
   {
     m_recentMenu->insertItem(*it);
-    m_settings.writeEntry(QString().sprintf("/recent/config%d",i),*it);
+    m_settings.writeEntry(QString().sprintf("/doxywizard/recent/config%d",i),*it);
   }
 }
 
