@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: classdef.cpp,v 1.54 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -86,6 +86,7 @@ ClassDef::ClassDef(
   m_innerClasses = new ClassSDict(17);
   m_subGrouping=Config_getBool("SUBGROUPING");
   m_templateInstances = 0;
+  m_variableInstances = 0;
   m_templateMaster =0;
   m_templBaseClassNames = 0;
   m_artificial = FALSE;
@@ -123,6 +124,7 @@ ClassDef::~ClassDef()
   delete memberGroupSDict;
   delete m_innerClasses;
   delete m_templateInstances;
+  delete m_variableInstances;
   delete m_templBaseClassNames;
   delete m_tempArgs;
 }
@@ -934,31 +936,108 @@ void ClassDef::writeDetailedDescription(OutputList &ol, const QCString &pageType
   }
 }
     
+void ClassDef::showUsedFiles(OutputList &ol)
+{
+  if (Config_getBool("SHOW_USED_FILES"))
+  {
+    ol.writeRuler();
+    ol.parseText(theTranslator->trGeneratedFromFiles(
+          m_isObjC && m_compType==Interface ? Class : m_compType,
+          m_files.count()==1));
+
+    bool first=TRUE;
+    const char *file = m_files.first();
+    while (file)
+    {
+      bool ambig;
+      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
+      if (fd)
+      {
+        if (first)
+        {
+          first=FALSE;   
+          ol.startItemList();
+        }
+
+        ol.writeListItem();
+        QCString path=fd->getPath().copy();
+        if (Config_getBool("FULL_PATH_NAMES"))
+        {
+          ol.docify(stripFromPath(path));
+        }
+
+        QCString fname = fd->name();
+        if (!fd->getVersion().isEmpty()) // append version if available
+        {
+          fname += " (" + fd->getVersion() + ")";
+        }
+
+        // for HTML 
+        ol.pushGeneratorState();
+        ol.disableAllBut(OutputGenerator::Html);
+        if (fd->generateSourceFile())
+        {
+          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fname);
+        }
+        else if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+        ol.popGeneratorState();
+
+        // for other output formats
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::Html);
+        if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+
+        ol.popGeneratorState();
+
+        
+      }
+      file=m_files.next();
+    }
+    if (!first) ol.endItemList();
+  }
+}
+
+
 // write all documentation for this class
 void ClassDef::writeDocumentation(OutputList &ol)
 {
-  // write title
-  QCString pageTitle=displayName().copy();
-  QCString pageType;
-  QCString cType=compoundTypeString();
-  //printf("ClassDef::writeDocumentation() cType=%s\n",cType.data());
-  toupper(cType.at(0));
-  pageType+=" ";
-  pageType+=cType;
-  pageTitle+=pageType+" Reference";
-  if (m_tempArgs) pageTitle.prepend(" Template");
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  QCString pageType = " ";
+  pageType += compoundTypeString();
+  toupper(pageType.at(1));
+  QCString pageTitle = theTranslator->trCompoundReference(displayName(),
+              m_compType == Interface && m_isObjC ? Class : m_compType,
+              m_tempArgs != 0);
+  
+  startFile(ol,getOutputFileBase(),name(),pageTitle);  
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
   startTitle(ol,getOutputFileBase());
-  ol.parseText(theTranslator->trCompoundReference(displayName(),
-               m_isObjC && m_compType==Interface ? Class : m_compType,
-               m_tempArgs!=0));
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),name());
 
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   ol.startTextBlock();
@@ -1261,6 +1340,11 @@ void ClassDef::writeDocumentation(OutputList &ol)
     writeDetailedDescription(ol,pageType,exampleFlag);
   }
 
+
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member declarations + brief descriptions
+  ///////////////////////////////////////////////////////////////////////////
+
   // write member groups
   ol.startMemberSections();
 
@@ -1346,6 +1430,10 @@ void ClassDef::writeDocumentation(OutputList &ol)
                   theTranslator->trRelatedFunctions(),
                   theTranslator->trRelatedSubscript()
                  ); 
+
+  // nested classes
+  m_innerClasses->writeDeclaration(ol,0,0,TRUE);
+
   ol.endMemberSections();
     
   // write detailed description
@@ -1353,6 +1441,54 @@ void ClassDef::writeDocumentation(OutputList &ol)
     writeDetailedDescription(ol,pageType,exampleFlag);
   }
   
+  writeMemberDocumentation(ol);
+
+  /////////////////////////////////////////////////////////////////////
+  ol.startTextBlock();
+
+  // write the list of used files (not for man pages)
+  ol.pushGeneratorState();
+  ol.disable(OutputGenerator::Man);
+
+  showUsedFiles(ol);
+
+  // write Author section (Man only)
+  ol.enable(OutputGenerator::Man);
+  ol.disableAllBut(OutputGenerator::Man);
+  ol.writeString("\n");
+  ol.startGroupHeader();
+  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
+  ol.endGroupHeader();
+  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+  ol.popGeneratorState();
+
+  ol.endTextBlock();
+  /////////////////////////////////////////////////////////////////////
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+ 
+  endFile(ol);
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    writeMemberPages(ol);
+  }
+}
+
+void ClassDef::writeMemberDocumentation(OutputList &ol)
+{
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member definitions + detailed documentation
+  ///////////////////////////////////////////////////////////////////////////
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
   
   typedefMembers.writeDocumentation(ol,name(),this,
                          theTranslator->trMemberTypedefDocumentation());
@@ -1378,102 +1514,77 @@ void ClassDef::writeDocumentation(OutputList &ol)
   eventMembers.writeDocumentation(ol,name(),this,
                          theTranslator->trEventDocumentation());
 
-  ol.startTextBlock();
-
-  // write the list of used files (not for man pages)
-  ol.pushGeneratorState();
-  ol.disable(OutputGenerator::Man);
-
-  if (Config_getBool("SHOW_USED_FILES"))
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    ol.writeRuler();
-    ol.parseText(theTranslator->trGeneratedFromFiles(
-          m_isObjC && m_compType==Interface ? Class : m_compType,
-          m_files.count()==1));
-
-    bool first=TRUE;
-    const char *file = m_files.first();
-    while (file)
-    {
-      bool ambig;
-      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
-      if (fd)
-      {
-        if (first)
-        {
-          first=FALSE;   
-          ol.startItemList();
-        }
-
-        ol.writeListItem();
-        QCString path=fd->getPath().copy();
-        if (Config_getBool("FULL_PATH_NAMES"))
-        {
-          ol.docify(stripFromPath(path));
-        }
-
-        // for HTML 
-        ol.pushGeneratorState();
-        ol.disableAllBut(OutputGenerator::Html);
-        if (fd->generateSourceFile())
-        {
-          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fd->name());
-        }
-        else if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-        ol.popGeneratorState();
-
-        // for other output formats
-        ol.pushGeneratorState();
-        ol.disable(OutputGenerator::Html);
-        if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-
-        ol.popGeneratorState();
-
-        
-      }
-      file=m_files.next();
-    }
-    if (!first) ol.endItemList();
+    ol.enable(OutputGenerator::Html);
   }
-
-  // write Author section (Man only)
-  ol.enable(OutputGenerator::Man);
-  ol.disableAllBut(OutputGenerator::Man);
-  ol.writeString("\n");
-  ol.startGroupHeader();
-  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
-  ol.endGroupHeader();
-  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
-  ol.popGeneratorState();
-
-  ol.endTextBlock();
-
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-  {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
-  }
- 
-  endFile(ol);
-
 }
 
+void ClassDef::writeMemberPages(OutputList &ol)
+{
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member definitions on separate pages
+  ///////////////////////////////////////////////////////////////////////////
+
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  
+  typedefMembers.writeDocumentationPage(ol,name(),this);
+  enumMembers.writeDocumentationPage(ol,name(),this);
+  constructors.writeDocumentationPage(ol,name(),this);
+  functionMembers.writeDocumentationPage(ol,name(),this);
+  relatedMembers.writeDocumentationPage(ol,name(),this);
+  variableMembers.writeDocumentationPage(ol,name(),this);
+  propertyMembers.writeDocumentationPage(ol,name(),this);
+  eventMembers.writeDocumentationPage(ol,name(),this);
+
+  ol.popGeneratorState();
+}
+
+void ClassDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberNameInfoSDict::Iterator mnili(*m_allMemberNameInfoSDict);
+  MemberNameInfo *mni;
+  for (;(mni=mnili.current());++mnili)
+  {
+    MemberNameInfoIterator mnii(*mni);
+    MemberInfo *mi;
+    for (mnii.toFirst();(mi=mnii.current());++mnii)
+    {
+      MemberDef *md=mi->memberDef;
+      if (md->getClassDef()==this && md->isLinkable())
+      {
+        ol.writeString("          <tr><td class=\"navtab\">");
+        if (md->isLinkableInProject())
+        {
+          if (md==currentMd) // selected item => highlight
+          {
+            ol.writeString("<a class=\"qindexHL\" ");
+          }
+          else
+          {
+            ol.writeString("<a class=\"qindex\" ");
+          }
+          ol.writeString("href=\"");
+          ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+          ol.writeString("\">");
+          ol.writeString(md->name());
+          ol.writeString("</a>");
+        }
+        ol.writeString("</td></tr>\n");
+      }
+    }
+  }
+
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
+}
+
+
+
 void ClassDef::writeDocumentationForInnerClasses(OutputList &ol)
 {
   // write inner classes after the parent, so the tag files contain
@@ -1965,12 +2076,9 @@ bool ClassDef::isBaseClass(ClassDef *bcd, bool followInstances,int level)
 
 static bool isStandardFunc(MemberDef *md)
 {
-  ClassDef *cd=md->getClassDef();
-  if (cd->templateMaster()) cd=cd->templateMaster();
   return md->name()=="operator=" || // assignment operator
-         md->name()==cd->localName() || // constructor
-         (md->name().find('~')!=-1 && 
-          md->name().find("operator")==-1); // destructor
+         md->isConstructor() ||     // constructor
+         md->isDestructor();        // destructor
 }
 
 /*! 
@@ -2492,8 +2600,8 @@ QCString ClassDef::compoundTypeString() const
     case Protocol:  return "protocol";
     case Category:  return "category";
     case Exception: return "exception";
+    default:        return "unknown";
   }
-  return "unknown";
 }
 
 QCString ClassDef::getOutputFileBase() const 
@@ -2642,6 +2750,26 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
   return templateClass;
 }
 
+ClassDef *ClassDef::getVariableInstance(const char *templSpec)
+{
+  if (m_variableInstances==0) 
+  {
+    m_variableInstances = new QDict<ClassDef>(17);
+    m_variableInstances->setAutoDelete(TRUE);
+  }
+  ClassDef *templateClass=m_variableInstances->find(templSpec);
+  if (templateClass==0)
+  {
+    Debug::print(Debug::Classes,0,"      New template variable instance class `%s'`%s'\n",name().data(),templSpec);
+    templateClass = new ClassDef("<code>",1,name()+templSpec,
+                        ClassDef::Class,0,0,FALSE);
+    templateClass->addMembersToTemplateInstance( this, templSpec );
+    templateClass->setTemplateMaster(this);
+    m_variableInstances->insert(templSpec,templateClass);
+  }
+  return templateClass;
+}
+
 void ClassDef::setTemplateBaseClassNames(QDict<int> *templateNames)
 {
   if (templateNames==0) return;
@@ -2806,6 +2934,8 @@ QCString ClassDef::className() const
 
 void ClassDef::addListReferences()
 {
+  if (!isLinkableInProject()) return;
+  //printf("ClassDef(%s)::addListReferences()\n",name().data());
   addRefItem(xrefListItems(),
              theTranslator->trClass(TRUE,TRUE),
              getOutputFileBase(),displayName()
