@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -67,7 +67,7 @@ class ClassDef : public Definition
                         Category=Entry::CATEGORY_SEC,
                         Exception=Entry::EXCEPTION_SEC
                       };
-    DefType definitionType() { return TypeClass; }
+    DefType definitionType() const { return TypeClass; }
     QCString getOutputFileBase() const; 
     QCString getInstanceOutputFileBase() const; 
     QCString getFileBase() const;
@@ -75,6 +75,7 @@ class ClassDef : public Definition
     QCString getReference() const;
     bool isReference() const;
     bool isLocal() const { return m_isLocal; }
+    bool isArtificial() const { return m_artificial; }
 
     bool hasDocumentation() const;
 
@@ -103,9 +104,12 @@ class ClassDef : public Definition
 
     void writeDocumentation(OutputList &ol);
     void writeDocumentationForInnerClasses(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
     void writeMemberList(OutputList &ol);
     void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
     void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
 
     /*! Return the protection level (Public,Protected,Private) in which 
      *  this compound was found.
@@ -160,6 +164,8 @@ class ClassDef : public Definition
      */
     ClassDef *templateMaster() const { return m_templateMaster; } 
 
+    bool isTemplate() const { return m_tempArgs!=0; }
+
     IncludeInfo *includeInfo() const { return m_incInfo; }
     
     UsesClassDict *usedImplementationClasses() const 
@@ -290,6 +296,7 @@ class ClassDef : public Definition
     //QCString getTemplateArgumentMapping(const char *formal) const;
     ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
                                 const QCString &templSpec,bool &freshInstance);
+    ClassDef *getVariableInstance(const char *templSpec);
     void setTemplateBaseClassNames(QDict<int> *templateNames);
     QDict<int> *getTemplateBaseClassNames() const;
     void setTemplateMaster(ClassDef *tm) { m_templateMaster=tm; }
@@ -329,6 +336,7 @@ class ClassDef : public Definition
     void addUsedInterfaceClasses(MemberDef *md,const char *typeStr);
     bool hasExamples();
     bool hasNonReferenceSuperClass();
+    void showUsedFiles(OutputList &ol);
 
     /*! \} Interal API */
 
@@ -416,6 +424,12 @@ class ClassDef : public Definition
      */ 
     QDict<ClassDef> *m_templateInstances;
 
+    /*! Template instances that exists of this class, as defined by variables.
+     *  We do NOT want to document these individually. The key in the
+     *  dictionary is the template argument list.
+     */ 
+    QDict<ClassDef> *m_variableInstances;
+
     QDict<int> *m_templBaseClassNames;
 
     /*! The class this class is an instance of. */
