@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -66,27 +66,27 @@ enum CommandType
   CMD_INTERNAL     = 32,         
   CMD_INTERNALREF  = 33,
   CMD_INVARIANT    = 34 | SIMPLESECT_BIT ,
-  CMD_LANGSWITCH   = 35,
-  CMD_LATEXONLY    = 36,
-  CMD_LESS         = 37,
-  CMD_LI           = 38,
-  CMD_LINE         = 39,
-  CMD_LINEBREAK    = 40,
-  CMD_LINK         = 41,             
-  CMD_NOTE         = 42 | SIMPLESECT_BIT,
-  CMD_PAR          = 43 | SIMPLESECT_BIT,
-  CMD_PARAM        = 44 | SIMPLESECT_BIT,
-  CMD_PERCENT      = 45, 
-  CMD_POST         = 46 | SIMPLESECT_BIT,
-  CMD_PRE          = 47 | SIMPLESECT_BIT ,
-  CMD_REF          = 48,
-  CMD_SECREFITEM   = 49,
-  CMD_REMARK       = 50 | SIMPLESECT_BIT ,
-  CMD_RETURN       = 51 | SIMPLESECT_BIT ,
-  CMD_RETVAL       = 52 | SIMPLESECT_BIT,
-  CMD_SA           = 53 | SIMPLESECT_BIT ,
-  CMD_SECREFLIST   = 54,
-  CMD_SECTION      = 55,
+  CMD_LATEXONLY    = 35,
+  CMD_LESS         = 36,
+  CMD_LI           = 37,
+  CMD_LINE         = 38,
+  CMD_LINEBREAK    = 39,
+  CMD_LINK         = 40,             
+  CMD_NOTE         = 41 | SIMPLESECT_BIT,
+  CMD_PAR          = 42 | SIMPLESECT_BIT,
+  CMD_PARAM        = 43 | SIMPLESECT_BIT,
+  CMD_PERCENT      = 44, 
+  CMD_POST         = 45 | SIMPLESECT_BIT,
+  CMD_PRE          = 46 | SIMPLESECT_BIT ,
+  CMD_REF          = 47,
+  CMD_SECREFITEM   = 48,
+  CMD_REMARK       = 49 | SIMPLESECT_BIT ,
+  CMD_RETURN       = 50 | SIMPLESECT_BIT ,
+  CMD_RETVAL       = 51 | SIMPLESECT_BIT,
+  CMD_SA           = 52 | SIMPLESECT_BIT ,
+  CMD_SECREFLIST   = 53,
+  CMD_SECTION      = 54,
+  CMD_SUBPAGE      = 55,
   CMD_SUBSECTION   = 56,
   CMD_SUBSUBSECTION= 57,
   CMD_PARAGRAPH    = 58,
