@@ -548,12 +548,11 @@
 "    </xsd:sequence>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"docParamName\">\n"
-"    <xsd:simpleContent>\n"
-"      <xsd:extension base=\"xsd:string\">\n"
-"        <xsd:attribute name=\"direction\" type=\"DoxParamDir\" use=\"optional\" />\n"
-"      </xsd:extension>\n"
-"    </xsd:simpleContent>\n"
+"  <xsd:complexType name=\"docParamName\" mixed=\"true\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"ref\" type=\"refTextType\" minOccurs=\"0\" maxOccurs=\"1\" />\n"
+"    </xsd:sequence>\n"
+"    <xsd:attribute name=\"direction\" type=\"DoxParamDir\" use=\"optional\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docXRefSectType\">\n"
