@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,6 +29,7 @@
 #include "code.h"
 #include "util.h"
 #include "groupdef.h"
+#include "pagedef.h"
 #include "section.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
@@ -164,7 +165,9 @@ void Definition::writeDocAnchorsToTagFile()
       {
         //printf("write an entry!\n");
         if (definitionType()==TypeMember) Doxygen::tagFile << "  ";
-        Doxygen::tagFile << "    <docanchor>" << si->label << "</docanchor>" << endl;
+        Doxygen::tagFile << "    <docanchor file=\"" 
+                         << si->fileName << "\">" << si->label 
+                         << "</docanchor>" << endl;
       }
     }
   }
@@ -214,10 +217,10 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
 void Definition::setBriefDescription(const char *b,const char *briefFile,int briefLine) 
 { 
   if (b==0) return;
-  //printf("Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
+  //fprintf(stderr,"Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
   m_brief=QCString(b).stripWhiteSpace();
   int bl=m_brief.length(); 
-  if (bl>0) // add puntuation if needed
+  if (bl>0) // add punctuation if needed
   {
     switch(m_brief.at(bl-1))
     {
@@ -246,7 +249,7 @@ static bool readCodeFragment(const char *fileName,
 {
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString cmd=Config_getString("INPUT_FILTER")+" \""+fileName+"\"";
+  QCString cmd=getFileFilter(fileName)+" \""+fileName+"\"";
   FILE *f = Config_getBool("FILTER_SOURCE_FILES") ? popen(cmd,"r") : fopen(fileName,"r");
   bool found=FALSE;
   if (f)
@@ -355,10 +358,6 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
   //printf("Definition::writeSourceRef %d %p\n",bodyLine,bodyDef);
   if (Config_getBool("SOURCE_BROWSER") && m_startBodyLine!=-1 && m_bodyDef)
   {
-    ol.disable(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.enableAll();
-
     QCString refText = theTranslator->trDefinedAtLineInSourceFile();
     int lineMarkerPos = refText.find("@0");
     int fileMarkerPos = refText.find("@1");
@@ -367,6 +366,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
       QCString lineStr,anchorStr;
       lineStr.sprintf("%d",m_startBodyLine);
       anchorStr.sprintf("l%05d",m_startBodyLine);
+      ol.newParagraph();
       if (lineMarkerPos<fileMarkerPos) // line marker before file marker
       {
         // write text left from linePos marker
@@ -436,10 +436,6 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
     {
       err("Error: translation error: invalid markers in trDefinedInSourceFile()\n");
     }
-
-    ol.disableAllBut(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.enableAll();
   }
   ol.popGeneratorState();
 }
@@ -462,11 +458,11 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
       initParseCodeContext();
       //printf("Read:\n`%s'\n\n",codeFragment.data());
       if (definitionType()==TypeMember) setParameterList((MemberDef *)this);
-      ol.newParagraph();
       ol.startCodeFragment();
       parseCode(ol,scopeName,codeFragment,FALSE,0,
           m_bodyDef,actualStart,actualEnd,TRUE);
       ol.endCodeFragment();
+      ol.newParagraph();
     }
   }
   ol.popGeneratorState();
@@ -568,12 +564,18 @@ void Definition::writeSourceRefList(OutputList &ol,const char *scopeName,
 
 void Definition::writeSourceReffedBy(OutputList &ol,const char *scopeName)
 {
-  writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_sourceRefByDict,FALSE);
+  if (Config_getBool("REFERENCED_BY_RELATION"))
+  {
+    writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_sourceRefByDict,FALSE);
+  }
 }
 
 void Definition::writeSourceRefs(OutputList &ol,const char *scopeName)
 {
-  writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_sourceRefsDict,TRUE);
+  if (Config_getBool("REFERENCES_RELATION"))
+  {
+    writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_sourceRefsDict,TRUE);
+  }
 }
 
 bool Definition::hasDocumentation() const
@@ -758,3 +760,62 @@ QCString Definition::convertNameToFile(const char *name,bool allowDots) const
   }
 }
 
+void Definition::writePathFragment(OutputList &ol) const
+{
+  if (m_outerScope && m_outerScope!=Doxygen::globalScope)
+  {
+    m_outerScope->writePathFragment(ol);
+    if (m_outerScope->definitionType()==Definition::TypeClass ||
+        m_outerScope->definitionType()==Definition::TypeNamespace)
+    {
+      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+      {
+        ol.writeString(".");
+      }
+      else
+      {
+        ol.writeString("::");
+      }
+    }
+    else
+    {
+      ol.writeString("&nbsp;");
+      ol.writeString("/");
+      ol.writeString("&nbsp;");
+    }
+  }
+  if (isLinkable())
+  {
+    if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const GroupDef*)this)->groupTitle());
+    }
+    else if (definitionType()==Definition::TypePage && !((const PageDef*)this)->title().isEmpty())
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const PageDef*)this)->title());
+    }
+    else
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_localName);
+    }
+  }
+  else
+  {
+    ol.startBold();
+    ol.docify(m_localName);
+    ol.endBold();
+  }
+}
+
+void Definition::writeNavigationPath(OutputList &ol) const
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+
+  ol.writeString("<div class=\"nav\">\n");
+  writePathFragment(ol);
+  ol.writeString("</div>\n");
+
+  ol.popGeneratorState();
+}
+
