@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -48,10 +48,10 @@ class Definition
     enum DefType 
     { 
       TypeClass, TypeMember, TypeFile, TypeGroup, 
-      TypeNamespace, TypePackage, TypePage
+      TypeNamespace, TypePackage, TypePage, TypeDir
     };
     /*! Use this for dynamic inspection of the type of the derived class */
-    virtual DefType definitionType() = 0;
+    virtual DefType definitionType() const = 0;
     
     /*! Create a new definition */
     Definition(
@@ -193,7 +193,13 @@ class Definition
     GroupList *partOfGroups() const { return m_partOfGroups; }
     QCString convertNameToFile(const char *name,bool allowDots=FALSE) const;
 
+    void writePathFragment(OutputList &ol) const;
+    void writeNavigationPath(OutputList &ol) const;
+    virtual void writeQuickMemberLinks(OutputList &,MemberDef *) const {}
+
   protected:
+    void setLocalName(const QCString name) { m_localName=name; }
+    
     int      m_startBodyLine;   // line number of the start of the definition
     int      m_endBodyLine;     // line number of the end of the definition
     FileDef *m_bodyDef;         // file definition containing the function body
