@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,6 +22,7 @@
 #include "qtbc.h"
 #include <qtextstream.h>
 #include <qdatetime.h>
+#include <qcache.h>
 #include "groupdef.h"
 #include "filedef.h"
 #include "classdef.h"
@@ -34,11 +35,13 @@
 #include "section.h"
 #include "membergroup.h"
 #include "reflist.h"
+#include "dirdef.h"
 
 class PageSList;
 class PageSDict;
 class PageDef;
 class SearchIndex;
+class DirDef;
 
 typedef QList<QCString>    StringList;
 typedef QDict<FileDef>     FileDict;
@@ -51,6 +54,15 @@ class StringDict : public QDict<QCString>
     virtual ~StringDict() {}
 };
 
+struct LookupInfo
+{
+  LookupInfo(ClassDef *cd=0,MemberDef *td=0,QCString ts="") 
+    : classDef(cd), typeDef(td), templSpec(ts) {}
+  ClassDef  *classDef;
+  MemberDef *typeDef;
+  QCString   templSpec;
+};
+
 
 extern QCString spaces;
 
@@ -101,6 +113,9 @@ class Doxygen
     static SDict<DefinitionList>    *symbolMap;
     static bool                      outputToWizard;
     static QDict<int>               *htmlDirMap;
+    static QCache<LookupInfo>        lookupCache;
+    static DirSDict                  directories;
+    static SDict<DirRelation>        dirRelations;
 };
 
 void initDoxygen();
@@ -108,4 +123,7 @@ void readConfiguration(int argc, char **argv);
 void parseInput();
 void generateOutput();
 
+//#undef USE_TMP_FILE
+#define USE_TMP_FILE 
+
 #endif
