@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,6 +38,7 @@ class NamespaceDef;
 class NamespaceSDict;
 class MemberGroupSDict;
 class PackageDef;
+class DirDef;
 
 struct IncludeInfo
 {
@@ -46,6 +47,7 @@ struct IncludeInfo
   FileDef *fileDef;
   QCString includeName;
   bool local;
+  bool imported;
 };
 
 /*! \class FileDef filedef.h
@@ -67,7 +69,7 @@ class FileDef : public Definition
 
     FileDef(const char *p,const char *n,const char *ref=0,const char *dn=0);
    ~FileDef();
-    DefType definitionType() { return TypeFile; }
+    DefType definitionType() const { return TypeFile; }
 
     /*! Returns the unique file name (this may include part of the path). */
     QCString name() const 
@@ -107,6 +109,9 @@ class FileDef : public Definition
     
     /*! Returns the absolute path of this file. */ 
     QCString getPath() const { return path; }
+
+    /*! Returns version of this file. */
+    QCString getVersion() const { return fileVersion; }
     
     bool isLinkableInProject() const
     {
@@ -121,6 +126,10 @@ class FileDef : public Definition
 
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
+
     void writeSource(OutputList &ol);
     void parseSource();
     friend void generatedFileNames();
@@ -132,6 +141,9 @@ class FileDef : public Definition
     void setPackageDef(PackageDef *pd) { package=pd; }
     PackageDef *packageDef() const { return package; }
     
+    void setDirDef(DirDef *dd) { dir=dd; }
+    DirDef *getDirDef() const { return dir; }
+
     void addUsingDirective(NamespaceDef *nd);
     NamespaceSDict *getUsedNamespaces() const { return usingDirList; }
     void addUsingDeclaration(Definition *def);
@@ -140,8 +152,8 @@ class FileDef : public Definition
 
     bool generateSourceFile() const;
 
-    void addIncludeDependency(FileDef *fd,const char *incName,bool local);
-    void addIncludedByDependency(FileDef *fd,const char *incName,bool local);
+    void addIncludeDependency(FileDef *fd,const char *incName,bool local,bool imported);
+    void addIncludedByDependency(FileDef *fd,const char *incName,bool local,bool imported);
     QList<IncludeInfo> *includeFileList() const { return includeList; }
     QList<IncludeInfo> *includedByFileList() const { return includedByList; }
 
@@ -151,6 +163,7 @@ class FileDef : public Definition
     void addIncludedUsingDirectives();
 
     void addListReferences();
+    bool isDocumentationFile() const;
 
     //void generateXML(QTextStream &t);
     //void generateXMLSection(QTextStream &t,MemberList *ml,const char *type);
@@ -181,6 +194,13 @@ class FileDef : public Definition
     
     bool visited;
 
+  protected:
+    /**
+     * Retrieves the file version from version control system.
+     */
+    void acquireFileVersion();
+
+
   private: 
     
     QDict<IncludeInfo> *includeDict;
@@ -189,19 +209,18 @@ class FileDef : public Definition
     QList<IncludeInfo> *includedByList;
     NamespaceSDict *usingDirList;
     SDict<Definition> *usingDeclList;
-    //DefineList *defineList;
     QCString path;
     QCString filepath;
     QCString diskname;
     QCString filename;
     QCString docname;
-    //QCString incName;
     QIntDict<Definition> *srcDefDict;
     QIntDict<MemberDef> *srcMemberDict;
     bool isSource;
-
+    QCString fileVersion;
 
     PackageDef *package;
+    DirDef     *dir;
 };
 
 
@@ -249,18 +268,23 @@ class DirEntry
   public:
     enum EntryKind { Dir, File };
     DirEntry(DirEntry *parent,FileDef *fd)  
-       : m_parent(parent), m_kind(File), m_fd(fd), m_isLast(FALSE) { }
-    DirEntry(DirEntry *parent)              
-       : m_parent(parent), m_kind(Dir), m_fd(0), m_isLast(FALSE) { }
+       : m_parent(parent), m_name(fd->name()), m_kind(File), m_fd(fd), 
+         m_isLast(FALSE) { }
+    DirEntry(DirEntry *parent,QCString name)              
+       : m_parent(parent), m_name(name), m_kind(Dir), 
+         m_fd(0), m_isLast(FALSE) { }
     virtual ~DirEntry() { }
     EntryKind kind() const { return m_kind; }
     FileDef *file()  const { return m_fd; }
     bool isLast() const    { return m_isLast; }
     void setLast(bool b)   { m_isLast=b; }
     DirEntry *parent() const { return m_parent; }
+    QCString name() const  { return m_name; }
+    QCString path() const  { return parent() ? parent()->path()+"/"+name() : name(); }
 
   protected:
     DirEntry *m_parent;
+    QCString m_name;
   private:
     EntryKind m_kind;
     FileDef   *m_fd;
@@ -272,21 +296,20 @@ class Directory : public DirEntry
 {
   public:
     Directory(Directory *parent,const QCString &name) 
-       : DirEntry(parent), m_name(name)
+       : DirEntry(parent,name)
     { m_children.setAutoDelete(TRUE); }
     virtual ~Directory()              {}
     void addChild(DirEntry *d)        { m_children.append(d); d->setLast(TRUE); }
     QList<DirEntry> &children()       { return m_children; }
     void rename(const QCString &name) { m_name=name; }
     void reParent(Directory *parent)  { m_parent=parent; }
-    QCString name() const             { return m_name; }
 
   private:
-    QCString m_name;
     QList<DirEntry> m_children;
 };
 
-void generateFileTree(QTextStream &t);
+//void generateFileTree(QTextStream &t);
+void generateFileTree();
 
 #endif
 
