@@ -1,8 +1,8 @@
 /******************************************************************************
  i
- * 
+ * $Id: formula.cpp,v 1.16 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -103,7 +103,9 @@ void FormulaList::generateBitmaps(const char *path)
   {
     //printf("Running latex...\n");
     //system("latex _formulas.tex </dev/null >/dev/null");
-    if (iSystem("latex","_formulas.tex")!=0)
+    QCString latexCmd = Config_getString("LATEX_CMD_NAME");
+    if (latexCmd.isEmpty()) latexCmd="latex";
+    if (iSystem(latexCmd,"_formulas.tex")!=0)
     {
       err("Problems running latex. Check your installation or look for typos in _formulas.tex!\n");
       formulaError=TRUE;
