@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,6 +16,7 @@
  */
 
 #include <ctype.h>
+#include <qregexp.h>
 #include "qtbc.h"
 #include "groupdef.h"
 #include "classdef.h"
@@ -32,16 +33,18 @@
 #include "pagedef.h"
 #include "docparser.h"
 #include "searchindex.h"
+#include "dot.h"
 
 GroupDef::GroupDef(const char *df,int dl,const char *na,const char *t,
                    const char *refFileName) : Definition(df,dl,na)
 {
   fileList = new FileList;
-  classSDict = new ClassSDict(257);
+  classSDict = new ClassSDict(17);
   groupList = new GroupList;
-  namespaceList = new NamespaceList;
-  pageDict = new PageSDict(257);
-  exampleDict = new PageSDict(257);
+  namespaceSDict = new NamespaceSDict(17);
+  pageDict = new PageSDict(17);
+  exampleDict = new PageSDict(17);
+  dirList = new DirList;
   allMemberList = new MemberList;
   allMemberNameInfoSDict = new MemberNameInfoSDict(17);
   if (refFileName)
@@ -79,12 +82,13 @@ GroupDef::~GroupDef()
   delete fileList;
   delete classSDict;
   delete groupList;
-  delete namespaceList;
+  delete namespaceSDict;
   delete pageDict;
   delete exampleDict;
   delete allMemberList;
   delete allMemberNameInfoSDict;
   delete memberGroupSDict;
+  delete dirList;
 }
 
 void GroupDef::setGroupTitle( const char *t )
@@ -149,9 +153,17 @@ void GroupDef::addClass(const ClassDef *cd)
 void GroupDef::addNamespace(const NamespaceDef *def)
 {
   if (Config_getBool("SORT_BRIEF_DOCS"))
-    namespaceList->inSort(def);  
+    namespaceSDict->inSort(def->name(),def);  
   else
-    namespaceList->append(def);
+    namespaceSDict->append(def->name(),def);
+}
+
+void GroupDef::addDir(const DirDef *def)
+{
+  if (Config_getBool("SORT_BRIEF_DOCS"))
+    dirList->inSort(def);  
+  else
+    dirList->append(def);
 }
 
 void GroupDef::addPage(PageDef *def)
@@ -403,7 +415,7 @@ int GroupDef::countMembers() const
 {
   return fileList->count()+
          classSDict->count()+
-         namespaceList->count()+
+         namespaceSDict->count()+
          groupList->count()+
          allMemberList->count()+
          pageDict->count()+
@@ -454,19 +466,41 @@ void GroupDef::writeDetailedDocumentation(OutputList &ol)
 void GroupDef::writeDocumentation(OutputList &ol)
 {
   ol.pushGeneratorState();
-  //ol.disable(OutputGenerator::Man);
   startFile(ol,getOutputFileBase(),name(),title);
   startTitle(ol,getOutputFileBase());
-  ol.docify(title);
+  ol.parseText(title);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),title);
 
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(title,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    static QRegExp we("[a-zA-Z_][a-zA-Z_0-9]*");
+    int i=0,p=0,l=0;
+    while ((i=we.match(title,p,&l))!=-1) // foreach word in the title
+    {
+      Doxygen::searchIndex->addWord(title.mid(i,l),TRUE);
+      p=i+l;
+    }
   }
 
+  if (Config_getBool("HAVE_DOT") && Config_getBool("GROUP_GRAPHS") )
+  {
+    DotGroupCollaboration graph(this);
+    if (!graph.isTrivial())
+    {
+      msg("Generating dependency graph for group %s\n",qualifiedName().data());
+      ol.pushGeneratorState();
+      ol.disable(OutputGenerator::Man);
+      ol.newParagraph();
+      ol.startGroupCollaboration();
+      ol.parseText(theTranslator->trCollaborationDiagram(title));
+      ol.endGroupCollaboration(graph);
+      ol.popGeneratorState();
+    }
+  }
+
+
   if (Config_getBool("DETAILS_AT_TOP"))
   {
     writeDetailedDocumentation(ol);
@@ -510,7 +544,7 @@ void GroupDef::writeDocumentation(OutputList &ol)
     while (fd)
     {
       ol.startMemberItem(0);
-      ol.docify("file ");
+      ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
       ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,fd->name());
       if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -531,35 +565,7 @@ void GroupDef::writeDocumentation(OutputList &ol)
   }
 
   // write list of namespaces
-  if (namespaceList->count()>0)
-  {
-    ol.startMemberHeader();
-    ol.parseText(theTranslator->trNamespaces());
-    ol.endMemberHeader();
-    ol.startMemberList();
-    NamespaceDef *nd=namespaceList->first();
-    while (nd)
-    {
-      ol.startMemberItem(0);
-      ol.docify("namespace ");
-      ol.insertMemberAlign();
-      ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,nd->name());
-      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-      {
-        Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
-      }
-      ol.endMemberItem();
-      if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
-      {
-        ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
-        ol.endMemberDescription();
-        ol.newParagraph();
-      }
-      nd=namespaceList->next();
-    }
-    ol.endMemberList();
-  }
+  namespaceSDict->writeDeclaration(ol);
 
   // write list of groups
   if (groupList->count()>0)
@@ -572,8 +578,8 @@ void GroupDef::writeDocumentation(OutputList &ol)
     while (gd)
     {
       ol.startMemberItem(0);
-      ol.docify(theTranslator->trGroup(FALSE,TRUE));
-      ol.docify(" ");
+      //ol.docify(theTranslator->trGroup(FALSE,TRUE));
+      //ol.docify(" ");
       ol.insertMemberAlign();
       ol.writeObjectLink(gd->getReference(),gd->getOutputFileBase(),0,gd->groupTitle());
       if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -593,6 +599,38 @@ void GroupDef::writeDocumentation(OutputList &ol)
     ol.endMemberList();
   }
 
+  // write list of directories
+  if (dirList->count()>0)
+  {
+    ol.startMemberHeader();
+    ol.parseText(theTranslator->trDirectories());
+    ol.endMemberHeader();
+    ol.startMemberList();
+    DirDef *dd=dirList->first();
+    while (dd)
+    {
+      ol.startMemberItem(0);
+      ol.parseText(theTranslator->trDir(FALSE,TRUE));
+      ol.insertMemberAlign();
+      ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),0,dd->shortName());
+      ol.endMemberItem();
+      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+      {
+        Doxygen::tagFile << "    <dir>" << convertToXML(dd->displayName()) << "</dir>" << endl;
+      }
+      if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+      {
+        ol.startMemberDescription();
+        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE);
+        ol.endMemberDescription();
+        ol.newParagraph();
+      }
+      dd=dirList->next();
+    }
+
+    ol.endMemberList();
+  }
+  
   // write list of classes
   classSDict->writeDeclaration(ol);
 
@@ -649,6 +687,32 @@ void GroupDef::writeDocumentation(OutputList &ol)
     }
   }
 
+  writeMemberDocumentation(ol);
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+
+  endFile(ol); 
+  ol.popGeneratorState();
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    allMemberList->sort();
+    writeMemberPages(ol);
+  }
+
+}
+
+void GroupDef::writeMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
+  
   docDefineMembers.writeDocumentation(ol,name(),this,
                              theTranslator->trDefineDocumentation());
   
@@ -667,16 +731,65 @@ void GroupDef::writeDocumentation(OutputList &ol)
   docVarMembers.writeDocumentation(ol,name(),this,
                              theTranslator->trVariableDocumentation());
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
+    ol.enable(OutputGenerator::Html);
   }
+}
+
+void GroupDef::writeMemberPages(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  
+  docDefineMembers.writeDocumentationPage(ol,name(),this);
+  docProtoMembers.writeDocumentationPage(ol,name(),this);
+  docTypedefMembers.writeDocumentationPage(ol,name(),this);
+  docEnumMembers.writeDocumentationPage(ol,name(),this);
+  docFuncMembers.writeDocumentationPage(ol,name(),this);
+  docVarMembers.writeDocumentationPage(ol,name(),this);
 
-  endFile(ol); 
   ol.popGeneratorState();
 }
 
+void GroupDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberListIterator mli(*allMemberList);
+  MemberDef *md;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    if (md->getGroupDef()==this && md->isLinkable())
+    {
+      ol.writeString("          <tr><td class=\"navtab\">");
+      if (md->isLinkableInProject())
+      {
+        if (md==currentMd) // selected item => highlight
+        {
+          ol.writeString("<a class=\"qindexHL\" ");
+        }
+        else
+        {
+          ol.writeString("<a class=\"qindex\" ");
+        }
+        ol.writeString("href=\"");
+        ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+        ol.writeString("\">");
+        ol.writeString(md->localName());
+        ol.writeString("</a>");
+      }
+      ol.writeString("</td></tr>\n");
+    }
+  }
+
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
+}
+
+
+
 //---- helper functions ------------------------------------------------------
 
 void addClassToGroups(Entry *root,ClassDef *cd)
@@ -713,6 +826,24 @@ void addNamespaceToGroups(Entry *root,NamespaceDef *nd)
   }
 }
 
+void addDirToGroups(Entry *root,DirDef *dd)
+{
+  //printf("*** root->groups->count()=%d\n",root->groups->count());
+  QListIterator<Grouping> gli(*root->groups);
+  Grouping *g;
+  for (;(g=gli.current());++gli)
+  {
+    GroupDef *gd=0;
+    //printf("group `%s'\n",g->groupname.data());
+    if (!g->groupname.isEmpty() && (gd=Doxygen::groupSDict[g->groupname]))
+    {
+      gd->addDir(dd);
+      dd->makePartOfGroup(gd);
+      //printf("Dir %s: in group %s\n",dd->name().data(),g->groupname.data());
+    }
+  }
+}
+
 void addGroupToGroups(Entry *root,GroupDef *subGroup)
 {
   QListIterator<Grouping> gli(*root->groups);
@@ -821,7 +952,8 @@ void addMemberToGroups(Entry *root,MemberDef *md)
       if (success)
       {
         //printf("insertMember successful\n");
-        md->setGroupDef(fgd,pri,root->fileName,root->startLine,!root->doc.isEmpty());
+        md->setGroupDef(fgd,pri,root->fileName,root->startLine,
+                        !root->doc.isEmpty());
         ClassDef *cd = md->getClassDefOfAnonymousType();
         if (cd) cd->setGroupDefForAllMembers(fgd,pri,root->fileName,root->startLine,root->doc.length() != 0);
       }
