@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -111,8 +111,8 @@ class HtmlDocVisitor : public DocVisitor
     void visitPost(DocSecRefItem *);
     void visitPre(DocSecRefList *);
     void visitPost(DocSecRefList *);
-    void visitPre(DocLanguage *);
-    void visitPost(DocLanguage *);
+    //void visitPre(DocLanguage *);
+    //void visitPost(DocLanguage *);
     void visitPre(DocParamSect *);
     void visitPost(DocParamSect *);
     void visitPre(DocParamList *);
@@ -137,7 +137,7 @@ class HtmlDocVisitor : public DocVisitor
     void startLink(const QString &ref,const QString &file,
                    const QString &relPath,const QString &anchor);
     void endLink();
-    void writeDotFile(const QString &fileName);
+    void writeDotFile(const QString &fileName,const QString &relPath);
 
     void pushEnabled();
     void popEnabled();
