@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlgen.cpp,v 1.56 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -35,6 +35,7 @@
 #include "index.h"
 #include "pagedef.h"
 #include "debug.h"
+#include "dirdef.h"
 
 // #define GROUP_COLOR "#ff8080"
 
@@ -42,61 +43,91 @@
 #define DBG_HTML(x) 
 
 static const char *defaultStyleSheet = 
-"H1 {\n"
-"	text-align: center;\n"
+"BODY,H1,H2,H3,H4,H5,H6,P,CENTER,TD,TH,UL,DL,DIV {\n"
 "	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
 "}\n"
+"BODY,TD {\n"
+"       font-size: 90%;\n"
+"}\n"
+"H1 {\n"
+"	text-align: center;\n"
+"       font-size: 160%;\n"
+"}\n"
 "H2 {\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
+"       font-size: 120%;\n"
+"}\n"
+"H3 {\n"
+"       font-size: 100%;\n"
 "}\n"
 "CAPTION { font-weight: bold }\n"
 "DIV.qindex {\n"
 "	width: 100%;\n"
 "	background-color: #eeeeff;\n"
-"	border: 1px solid #B0B0B0;\n"
+"	border: 1px solid #b0b0b0;\n"
 "	text-align: center;\n"
 "	margin: 2px;\n"
 "	padding: 2px;\n"
-"	line-height: 120%;\n"
+"	line-height: 140%;\n"
+"}\n"
+"DIV.nav {\n"
+"	width: 100%;\n"
+"	background-color: #eeeeff;\n"
+"	border: 1px solid #b0b0b0;\n"
+"	text-align: center;\n"
+"	margin: 2px;\n"
+"	padding: 2px;\n"
+"	line-height: 140%;\n"
+"}\n"
+"DIV.navtab {\n"
+"       background-color: #eeeeff;\n"
+"       border: 1px solid #b0b0b0;\n"
+"       text-align: center;\n"
+"       margin: 2px;\n"
+"       margin-right: 15px;\n"
+"       padding: 2px;\n"
+"}\n"
+"TD.navtab {\n"
+"       font-size: 70%;\n"
 "}\n"
 "A.qindex {\n"
 "       text-decoration: none;\n"
 "       font-weight: bold;\n"
 "       color: #1A419D;\n"
-"       padding: 2px;\n"
 "}\n"
 "A.qindex:visited {\n"
 "       text-decoration: none;\n"
 "       font-weight: bold;\n"
 "       color: #1A419D\n"
-"       padding: 2px;\n"
 "}\n"
 "A.qindex:hover {\n"
 "	text-decoration: none;\n"
 "	background-color: #ddddff;\n"
-"	padding: 2px;\n"
 "}\n"
 "A.qindexHL {\n"
 "	text-decoration: none;\n"
 "	font-weight: bold;\n"
 "	background-color: #6666cc;\n"
 "	color: #ffffff;\n"
-"	padding: 2px 6px;\n"
 "	border: 1px double #9295C2;\n"
 "}\n"
 "A.qindexHL:hover {\n"
 "	text-decoration: none;\n"
 "	background-color: #6666cc;\n"
 "	color: #ffffff;\n"
-"	padding: 2px 6px;\n"
 "}\n"
 "A.qindexHL:visited { text-decoration: none; background-color: #6666cc; color: #ffffff }\n"
 "A.el { text-decoration: none; font-weight: bold }\n"
 "A.elRef { font-weight: bold }\n"
-"A.code { text-decoration: none; font-weight: normal; color: #1A419D}\n"
-"A.codeRef { font-weight: normal; color: #1A419D}\n"
+"A.code:link { text-decoration: none; font-weight: normal; color: #0000FF}\n"
+"A.code:visited { text-decoration: none; font-weight: normal; color: #0000FF}\n"
+"A.codeRef:link { font-weight: normal; color: #0000FF}\n"
+"A.codeRef:visited { font-weight: normal; color: #0000FF}\n"
 "A:hover { text-decoration: none; background-color: #f2f2ff }\n"
 "DL.el { margin-left: -1cm }\n"
+".fragment {\n"
+"       font-family: Fixed, monospace;\n"
+"       font-size: 95%;\n"
+"}\n"
 "PRE.fragment {\n"
 "	border: 1px solid #CCCCCC;\n"
 "	background-color: #f5f5f5;\n"
@@ -109,13 +140,19 @@ static const char *defaultStyleSheet =
 "	padding-top: 4px;\n"
 "	padding-bottom: 4px;\n"
 "}\n"
-"DIV.fragment {\n"
-"	border: 1px solid #CCCCCC;\n"
-"	background-color: #f5f5f5;\n"
-"	padding: 6px;\n"
-"}\n"
+//"DIV.fragment {\n"
+//"       font-family: monospace\n"
+//"	border: 1px solid #CCCCCC;\n"
+//"	background-color: #f5f5f5;\n"
+//"	padding: 6px;\n"
+//"}\n"
 "DIV.ah { background-color: black; font-weight: bold; color: #ffffff; margin-bottom: 3px; margin-top: 3px }\n"
 "TD.md { background-color: #F4F4FB; font-weight: bold; }\n"
+"TD.mdPrefix {\n"
+"       background-color: #F4F4FB;\n"
+"       color: #606060;\n"
+"	font-size: 80%;\n"
+"}\n"
 "TD.mdname1 { background-color: #F4F4FB; font-weight: bold; color: #602020; }\n"
 "TD.mdname { background-color: #F4F4FB; font-weight: bold; color: #602020; width: 600px; }\n"
 "DIV.groupHeader {\n"
@@ -123,9 +160,8 @@ static const char *defaultStyleSheet =
 "       margin-top: 12px;\n"
 "       margin-bottom: 6px;\n"
 "       font-weight: bold;\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
 "}\n"
-"DIV.groupText { margin-left: 16px; font-style: italic; font-size: smaller }\n"
+"DIV.groupText { margin-left: 16px; font-style: italic; font-size: 90% }\n"
 "BODY {\n"
 "	background: white;\n"
 "	color: black;\n"
@@ -179,10 +215,10 @@ static const char *defaultStyleSheet =
 "	padding: 8px 10px;\n"
 "}\n"
 ".mdescLeft {\n"
-"	font-size: smaller;\n"
+"       padding: 0px 8px 4px 8px;\n"
+"	font-size: 80%;\n"
 "	font-style: italic;\n"
 "	background-color: #FAFAFA;\n"
-"	padding-left: 8px;\n"
 "	border-top: 1px none #E0E0E0;\n"
 "	border-right: 1px none #E0E0E0;\n"
 "	border-bottom: 1px none #E0E0E0;\n"
@@ -190,17 +226,15 @@ static const char *defaultStyleSheet =
 "	margin: 0px;\n"
 "}\n"
 ".mdescRight {\n"
-"	font-size: smaller;\n"
+"       padding: 0px 8px 4px 8px;\n"
+"	font-size: 80%;\n"
 "	font-style: italic;\n"
 "	background-color: #FAFAFA;\n"
-"	padding-left: 4px;\n"
 "	border-top: 1px none #E0E0E0;\n"
 "	border-right: 1px none #E0E0E0;\n"
 "	border-bottom: 1px none #E0E0E0;\n"
 "	border-left: 1px none #E0E0E0;\n"
 "	margin: 0px;\n"
-"	padding-bottom: 0px;\n"
-"	padding-right: 8px;\n"
 "}\n"
 ".memItemLeft {\n"
 "	padding: 1px 0px 0px 8px;\n"
@@ -209,36 +243,89 @@ static const char *defaultStyleSheet =
 "	border-right-width: 1px;\n"
 "	border-bottom-width: 1px;\n"
 "	border-left-width: 1px;\n"
-"	border-top-style: solid;\n"
 "	border-top-color: #E0E0E0;\n"
 "	border-right-color: #E0E0E0;\n"
 "	border-bottom-color: #E0E0E0;\n"
 "	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
 "	border-right-style: none;\n"
 "	border-bottom-style: none;\n"
 "	border-left-style: none;\n"
 "	background-color: #FAFAFA;\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
-"	font-size: 12px;\n"
+"	font-size: 80%;\n"
 "}\n"
 ".memItemRight {\n"
+"	padding: 1px 8px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
+"}\n"
+".memTemplItemLeft {\n"
 "	padding: 1px 0px 0px 8px;\n"
 "	margin: 4px;\n"
 "	border-top-width: 1px;\n"
 "	border-right-width: 1px;\n"
 "	border-bottom-width: 1px;\n"
 "	border-left-width: 1px;\n"
-"	border-top-style: solid;\n"
 "	border-top-color: #E0E0E0;\n"
 "	border-right-color: #E0E0E0;\n"
 "	border-bottom-color: #E0E0E0;\n"
 "	border-left-color: #E0E0E0;\n"
+"	border-top-style: none;\n"
 "	border-right-style: none;\n"
 "	border-bottom-style: none;\n"
 "	border-left-style: none;\n"
 "	background-color: #FAFAFA;\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
-"	font-size: 13px;\n"
+"	font-size: 80%;\n"
+"}\n"
+".memTemplItemRight {\n"
+"	padding: 1px 8px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: none;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
+"}\n"
+".memTemplParams {\n"
+"	padding: 1px 0px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"       color: #606060;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
 "}\n"
 ".search     { color: #003399;\n"
 "              font-weight: bold;\n"
@@ -259,8 +346,21 @@ static const char *defaultStyleSheet =
 "}\n"
 "a:visited {\n"
 "	color: #3D2185;\n"
+"}\n"
+".dirtab { padding: 4px;\n"
+"          border-collapse: collapse;\n"
+"          border: 1px solid #b0b0b0;\n"
+"}\n"
+"TH.dirtab { background: #eeeeff;\n"
+"            font-weight: bold;\n"
+"}\n"
+"HR { height: 1px;\n"
+"     border: none;\n"
+"     border-top: 1px solid black;\n"
 "}\n";
 
+
+
 static QCString g_header;
 static QCString g_footer;
 
@@ -311,6 +411,12 @@ void HtmlGenerator::writeStyleSheetFile(QFile &file)
 static void writeDefaultHeaderFile(QTextStream &t, const char *title,
                                    const char *relPath,bool usePathCmd)
 {
+  QString relPathStr;
+  if (usePathCmd) 
+    relPathStr="$relpath$";
+  else
+    relPathStr=relPath;
+
   t << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n"
     "<html><head>" 
     "<meta http-equiv=\"Content-Type\" content=\"text/html;charset=" 
@@ -322,11 +428,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title,
   t << "href=\"";
   if (Config_getString("HTML_STYLESHEET").isEmpty())
   {
-    if (usePathCmd) 
-      t << "$relpath$";
-    else
-      t << relPath;
-    t << "doxygen.css";
+    t << relPathStr << "doxygen.css";
   }
   else
   {
@@ -336,7 +438,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title,
     {
       err("Error: user specified HTML style sheet file does not exist!\n");
     }
-    t << cssfi.fileName();
+    t << relPathStr << cssfi.fileName();
   }
   t << "\" rel=\"stylesheet\" type=\"text/css\">\n"
     "</head><body>\n";
@@ -357,9 +459,9 @@ void HtmlGenerator::writeFooterFile(QFile &file)
   QTextStream t(&file);
   t << "<hr size=\"1\"><address style=\"align: right;\"><small>\n";
   t << theTranslator->trGeneratedAt( "$datetime", "$projectname" );
-  t << " <a href=\"http://www.doxygen.org/index.html\">"
+  t << "&nbsp;<a href=\"http://www.doxygen.org/index.html\">"
     << "<img src=\"doxygen.png\" alt=\"doxygen\" " 
-    << "align=\"middle\" border=0>"
+    << "align=\"middle\" border=\"0\">"
     << "</a> $doxygenversion";
   t << "</small></address>\n"
     << "</body>\n"
@@ -399,40 +501,12 @@ void HtmlGenerator::startFile(const char *name,const char *,
   }
   else
   {
-    t << substituteKeywords(g_header,convertToHtml(lastTitle),relPath);
+    t << substituteKeywords(g_header,convertToHtml(dispTitle),relPath);
   }
   t << "<!-- " << theTranslator->trGeneratedBy() << " Doxygen " 
     << versionString << " -->" << endl;
 }
 
-//void HtmlGenerator::startQuickIndexItem(const char *s,const char *l)
-//{
-//  QCString *dest;
-//  if (s) 
-//  {
-//    t << "<a class=\"qindexRef\" ";
-//    t << "doxygen=\"" << s << ":";
-//    if ((dest=Doxygen::tagDestinationDict[s])) t << *dest;
-//    if (strcmp(s,"_cgi")!=0) t << "/"; // small hack to get the cgi binary link right
-//    t << "\" ";
-//  }
-//  else
-//  {
-//    t << "<a class=\"qindex\" ";
-//  }
-//  t << "href=\""; 
-//  if (s)
-//  {
-//    if ((dest=Doxygen::tagDestinationDict[s])) t << *dest;
-//    if (strcmp(s,"_cgi")!=0) t << "/";
-//  }
-//  t << l << "\">";
-//}
-//
-//void HtmlGenerator::endQuickIndexItem()
-//{
-//  t << "</a> &nbsp; ";
-//}
 
 static void writePageFooter(QTextStream &t,const QCString &lastTitle,
                             const QCString relPath)
@@ -444,9 +518,9 @@ static void writePageFooter(QTextStream &t,const QCString &lastTitle,
         dateToString(TRUE),
         Config_getString("PROJECT_NAME")
         );
-    t << endl << "<a href=\"http://www.doxygen.org/index.html\">";
+    t << "&nbsp;" << endl << "<a href=\"http://www.doxygen.org/index.html\">";
     t << endl << "<img src=\"" << relPath << "doxygen.png\" alt=\"doxygen\" " 
-      << "align=\"middle\" border=0 >" << "</a> " << versionString << " ";
+      << "align=\"middle\" border=\"0\">" << "</a> " << versionString << " ";
     t << "</small></address>";
     if (Debug::isFlagSet(Debug::Validate))
     {
@@ -527,7 +601,7 @@ void HtmlGenerator::writeStyleInfo(int part)
 void HtmlGenerator::startDoxyAnchor(const char *,const char *,
                                     const char *anchor, const char *name)
 {
-  t << "<a class=\"anchor\" name=\"" << anchor << "\" doxytag=\"" << name << "\" ></a>";
+  t << "<a class=\"anchor\" name=\"" << anchor << "\" doxytag=\"" << name << "\"></a>";
 }
 
 void HtmlGenerator::endDoxyAnchor(const char *,const char *)
@@ -770,8 +844,10 @@ void HtmlGenerator::codify(const char *str)
                    t << spaces.left(spacesToNextTabStop); 
                    col+=spacesToNextTabStop; 
                    break; 
-        case '\n': t << '\n'; col=0; 
+        case '\n': t << "\n"; col=0; 
                    break;
+        //case '\n': t << "<br>"; col=0; 
+        //           break;
         case '\r': break;
         case '<':  t << "&lt;"; col++; 
                    break;
@@ -779,6 +855,8 @@ void HtmlGenerator::codify(const char *str)
                    break;
         case '&':  t << "&amp;"; col++; 
                    break;
+        //case ' ':  t << "&nbsp;"; col++;
+        //           break;
         case '\\':
                    if (*p=='<')
                      { t << "&lt;"; p++; }
@@ -813,11 +891,11 @@ void HtmlGenerator::endClassDiagram(ClassDiagram &d,
                                 const char *fileName,const char *name)
 {
   t << "\n<p><center><img src=\""
-    << fileName << ".png\" usemap=\"#" << name << "_map\""
+    << relPath << fileName << ".png\" usemap=\"#" << name << "_map\""
     << " border=\"0\" alt=\"\"></center>" << endl
     << "<map name=\"" << name << "_map\">" << endl;
 
-  d.writeImage(t,dir,fileName);
+  d.writeImage(t,dir,relPath,fileName);
 }
 
 
@@ -857,9 +935,10 @@ void HtmlGenerator::startMemberItem(int annoType)
     t << "<tr>";
     switch(annoType)
     {
-      case 0:  t << "<td class=\"memItemLeft\" nowrap align=right valign=top>"; break;
+      case 0:  t << "<td class=\"memItemLeft\" nowrap align=\"right\" valign=\"top\">"; break;
       case 1:  t << "<td class=\"memItemLeft\" nowrap>"; break;
-      default: t << "<td class=\"memItemLeft\" nowrap valign=top>"; break;
+      case 2:  t << "<td class=\"memItemLeft\" nowrap valign=\"top\">"; break;
+      default: t << "<td class=\"memTemplParams\" nowrap colspan=\"2\">"; break;
     }
   }
   else
@@ -878,13 +957,27 @@ void HtmlGenerator::endMemberItem()
   t << endl; 
 }
 
+void HtmlGenerator::startMemberTemplateParams()
+{
+}
 
-void HtmlGenerator::insertMemberAlign() 
+void HtmlGenerator::endMemberTemplateParams()
+{
+  if (Config_getBool("HTML_ALIGN_MEMBERS"))
+  {
+    t << "</td></tr>" << endl;
+    t << "<tr><td class=\"memTemplItemLeft\" nowrap align=\"right\" valign=\"top\">";
+  }
+}
+
+
+void HtmlGenerator::insertMemberAlign(bool templ) 
 { 
   DBG_HTML(t << "<!-- insertMemberAlign -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "&nbsp;</td><td class=\"memItemRight\" valign=bottom>"; 
+    QCString className = templ ? "memTemplItemRight" : "memItemRight";
+    t << "&nbsp;</td><td class=\"" << className << "\" valign=\"bottom\">"; 
   }
 }
 
@@ -906,11 +999,11 @@ void HtmlGenerator::endMemberDescription()
   DBG_HTML(t << "<!-- endMemberDescription -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<br><br></td></tr>" << endl; 
+    t << "<br></td></tr>" << endl; 
   }
   else
   {
-    t << "<br><br></dl>";
+    t << "<br></dl>";
   }
 }
 
@@ -919,7 +1012,7 @@ void HtmlGenerator::startMemberSections()
   DBG_HTML(t << "<!-- startMemberSections -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<table border=0 cellpadding=0 cellspacing=0>" << endl;
+    t << "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">" << endl;
     // HTML is not recursively decomposable, sorry
     t << "<tr><td></td></tr>" << endl;
   }
@@ -939,7 +1032,7 @@ void HtmlGenerator::startMemberHeader()
   DBG_HTML(t << "<!-- startMemberHeader -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<tr><td colspan=2><br><h2>";
+    t << "<tr><td colspan=\"2\"><br><h2>";
   }
   else
   {
@@ -963,7 +1056,7 @@ void HtmlGenerator::endMemberHeader()
 void HtmlGenerator::startMemberSubtitle()
 {
   DBG_HTML(t << "<!-- startMemberSubtitle -->" << endl)
-  if (Config_getBool("HTML_ALIGN_MEMBERS")) t << "<tr><td colspan=2>";
+  if (Config_getBool("HTML_ALIGN_MEMBERS")) t << "<tr><td colspan=\"2\">";
 }
 
 void HtmlGenerator::endMemberSubtitle()
@@ -1008,7 +1101,7 @@ void HtmlGenerator::startMemberDoc(const char *,const char *,const char *,const
 { 
   DBG_HTML(t << "<!-- startMemberDoc -->" << endl;)
   t << "<p>" << endl;
-  t << "<table class=\"mdTable\" width=\"100%\" cellpadding=\"2\" cellspacing=\"0\">" << endl;
+  t << "<table class=\"mdTable\" cellpadding=\"2\" cellspacing=\"0\">" << endl;
   t << "  <tr>" << endl;
   t << "    <td class=\"mdRow\">" << endl; 
   t << "      <table cellpadding=\"0\" cellspacing=\"0\" border=\"0\">" << endl;
@@ -1018,7 +1111,7 @@ void HtmlGenerator::startMemberDocPrefixItem()
 {
   DBG_HTML(t << "<!-- startMemberDocPrefixItem -->" << endl;)
   t << "        <tr>" << endl;
-  t << "          <td class=\"md\" colspan=\"4\">" << endl; 
+  t << "          <td class=\"mdPrefix\" colspan=\"4\">" << endl; 
 }
 
 void HtmlGenerator::endMemberDocPrefixItem()
@@ -1034,7 +1127,7 @@ void HtmlGenerator::startMemberDocName(bool align)
   t << "        <tr>" << endl;
   t << "          <td class=\"md\" nowrap valign=\"top\"";
   if (align) t << " align=\"right\"";
-  t << "> ";
+  t << ">";
 }
 
 void HtmlGenerator::endMemberDocName()
@@ -1068,7 +1161,7 @@ void HtmlGenerator::startParameterType(bool first,const char *key)
     t << "          <td class=\"md\" nowrap align=\"right\">";
     if (key) t << key;
     t << "</td>" << endl;
-    t << "          <td></td>" << endl;
+    t << "          <td class=\"md\"></td>" << endl;
     t << "          <td class=\"md\" nowrap>";
   }
 }
@@ -1108,7 +1201,7 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
       t << "</td>" << endl;
       t << "        </tr>" << endl;
       t << "        <tr>" << endl;
-      t << "          <td></td>" << endl;
+      t << "          <td class=\"md\"></td>" << endl;
       t << "          <td class=\"md\">";
       if (closeBracket) t << ")";
       t << "&nbsp;</td>" << endl;
@@ -1160,6 +1253,17 @@ void HtmlGenerator::endInclDepGraph(DotInclDepGraph &g)
   g.writeGraph(t,BITMAP,dir,relPath);
 }
 
+
+void HtmlGenerator::startGroupCollaboration()
+{
+}
+
+void HtmlGenerator::endGroupCollaboration(DotGroupCollaboration &g)
+{
+  g.writeGraph(t,BITMAP,dir,relPath);
+}
+
+
 void HtmlGenerator::startCallGraph()
 {
 }
@@ -1169,6 +1273,15 @@ void HtmlGenerator::endCallGraph(DotCallGraph &g)
   g.writeGraph(t,BITMAP,dir,relPath);
 }
 
+void HtmlGenerator::startDirDepGraph()
+{
+}
+
+void HtmlGenerator::endDirDepGraph(DotDirDeps &g)
+{
+  g.writeGraph(t,BITMAP,dir,relPath);
+}
+
 void HtmlGenerator::writeGraphicalHierarchy(DotGfxHierarchyTable &g)
 {
   g.writeGraph(t,dir);
@@ -1211,7 +1324,7 @@ void HtmlGenerator::startIndent()
   
   //t << "<div class=\"in\">" << endl; 
 
-  t << "<table cellspacing=5 cellpadding=0 border=0>\n"
+  t << "<table cellspacing=\"5\" cellpadding=\"0\" border=\"0\">\n"
        "  <tr>\n"
        "    <td>\n"
        "      &nbsp;\n"
@@ -1403,6 +1516,13 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
     t << fixSpaces(theTranslator->trCompoundList());
     endQuickIndexItem(t);
   } 
+  if (Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0)
+  {
+    startQuickIndexItem(t,"dirs"+Doxygen::htmlFileExtension,
+                        hli==HLI_Directories,compact,first,relPath);
+    t << fixSpaces(theTranslator->trDirectories());
+    endQuickIndexItem(t);
+  } 
   if (documentedHtmlFiles>0)
   {
     startQuickIndexItem(t,"files"+Doxygen::htmlFileExtension,
@@ -1498,7 +1618,7 @@ void HtmlGenerator::writeSearchPage()
 #endif
       if (g_header.isEmpty()) 
       {
-        writeDefaultHeaderFile(t,"Search",0,FALSE);
+        writeDefaultHeaderFile(t,theTranslator->trSearch().data(),0,FALSE);
       }
       else
       {
@@ -1535,7 +1655,7 @@ void HtmlGenerator::writeSearchPage()
       t << "\n";
       t << "function report_matches()\n";
       t << "{\n";
-      t << " return \"" << theTranslator->trSearchMatches() << " \";\n";
+      t << "  return \"" << theTranslator->trSearchMatches() << " \";\n";
       t << "}\n";
       t << "\n";
       t << search_script;
