@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,9 @@
 #include "qtbc.h"
 #include "outputgen.h"
 
+#define PREFRAG_START "<div class=\"fragment\"><pre class=\"fragment\">"
+#define PREFRAG_END   "</pre></div>"
+
 class QFile;
 
 class HtmlGenerator : public OutputGenerator
@@ -33,7 +36,8 @@ class HtmlGenerator : public OutputGenerator
     static void writeHeaderFile(QFile &f);
     static void writeFooterFile(QFile &f);
    
-    void enable() { active=TRUE; }
+    void enable() 
+    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
     void enableIf(OutputType o)  { if (o==Html) active=TRUE;  }
     void disableIf(OutputType o) { if (o==Html) active=FALSE; }
@@ -97,6 +101,8 @@ class HtmlGenerator : public OutputGenerator
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams();
+    void endMemberTemplateParams();
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -105,15 +111,15 @@ class HtmlGenerator : public OutputGenerator
     void startMemberGroup();
     void endMemberGroup(bool);
 
-    void insertMemberAlign();
+    void insertMemberAlign(bool);
     void startMemberDescription();
     void endMemberDescription();
 
     void writeRuler()    { t << "<hr>"; }
     void writeAnchor(const char *,const char *name) 
                          { t << "<a name=\"" << name <<"\"></a>"; }
-    void startCodeFragment() { t << "<pre class=\"fragment\"><div>"; }
-    void endCodeFragment()   { t << "</div></pre>"; } 
+    void startCodeFragment() { t << PREFRAG_START; }
+    void endCodeFragment()   { t << PREFRAG_END; } 
     void writeLineNumber(const char *,const char *,const char *,int);
     void startCodeLine() { col=0; }
     void endCodeLine()   { codify("\n"); }
@@ -169,11 +175,11 @@ class HtmlGenerator : public OutputGenerator
     void writeNonBreakableSpace(int);
     
     void startDescTable()
-    { t << "<table border=0 cellspacing=2 cellpadding=0>" << endl; }
+    { t << "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl; }
     void endDescTable()
     { t << "</table>" << endl; }
     void startDescTableTitle()
-    { t << "<tr><td valign=top><em>"; }
+    { t << "<tr><td valign=\"top\"><em>"; }
     void endDescTableTitle()
     { t << "</em>&nbsp;</td>"; }
     void startDescTableData()
@@ -185,12 +191,16 @@ class HtmlGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &g);
     void startInclDepGraph();
     void endInclDepGraph(DotInclDepGraph &g);
+    void startGroupCollaboration();
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
     void endCallGraph(DotCallGraph &g);
+    void startDirDepGraph();
+    void endDirDepGraph(DotDirDeps &g);
     void writeGraphicalHierarchy(DotGfxHierarchyTable &g);
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem();
