@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlhelp.cpp,v 1.8 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -37,6 +37,7 @@ struct IndexField
   QCString url;
   QCString anchor;
   bool     link;
+  bool     reversed;
 };
 
 class IndexFieldList : public QList<IndexField>
@@ -72,7 +73,8 @@ class HtmlHelpIndex
     HtmlHelpIndex();
    ~HtmlHelpIndex();
     void addItem(const char *first,const char *second, 
-                 const char *url, const char *anchor,bool hasLink);
+                 const char *url, const char *anchor,
+                 bool hasLink,bool reversed);
     void writeFields(QTextStream &t);
   private:
     IndexFieldList *list;
@@ -104,9 +106,12 @@ HtmlHelpIndex::~HtmlHelpIndex()
  *  \param anchor the anchor of the documentation within the page.
  *  \param hasLink if true, the url (without anchor) can be used in the 
  *         level1 item, when writing the header of a list of level2 items.
+ *  \param reversed TRUE if level1 is the member name and level2 the compound
+ *         name.
  */
 void HtmlHelpIndex::addItem(const char *level1,const char *level2,
-                       const char *url,const char *anchor,bool hasLink)
+                       const char *url,const char *anchor,bool hasLink,
+                       bool reversed)
 {
   QCString key = level1; 
   if (level2) key+= (QCString)"?" + level2;
@@ -115,10 +120,11 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
     //printf(">>>>>>>>> HtmlHelpIndex::addItem(%s,%s,%s,%s)\n",
     //      level1,level2,url,anchor);
     IndexField *f = new IndexField;
-    f->name   = key;
-    f->url    = url;
-    f->anchor = anchor;
-    f->link   = hasLink;
+    f->name     = key;
+    f->url      = url;
+    f->anchor   = anchor;
+    f->link     = hasLink;
+    f->reversed = reversed;
     list->inSort(f);
     dict->insert(key,f);
   }
@@ -175,11 +181,31 @@ void HtmlHelpIndex::writeFields(QTextStream &t)
       if (level2Started) t << "  </UL>" << endl;
       level2Started=FALSE;
     
+      // <Antony>
+      // Added this code so that an item with only one subitem is written
+      // without any subitem.
+      // For example:
+      //   a1, b1 -> will create only a1, not separate subitem for b1
+      //   a2, b2
+      //   a2, b3
+      QCString nextLevel1;
+      IndexField* fnext = ++ifli;
+      if (fnext)
+      {
+        nextLevel1 = fnext->name.left(fnext->name.find('?'));
+        --ifli;
+      }
+      if (level1 != nextLevel1)
+      {
+        level2 = "";
+      }
+      // </Antony>
+
       if (level2.isEmpty())
       {
         t << "  <LI><OBJECT type=\"text/sitemap\">";
         t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension;
-        if (!f->anchor.isEmpty()) t << "#" << f->anchor;  
+        if (!f->anchor.isEmpty() && f->reversed) t << "#" << f->anchor;  
         t << "\">";
         t << "<param name=\"Name\" value=\"" << level1 << "\">"
            "</OBJECT>\n";
@@ -189,7 +215,9 @@ void HtmlHelpIndex::writeFields(QTextStream &t)
         if (f->link)
         {
           t << "  <LI><OBJECT type=\"text/sitemap\">";
-          t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension << "\">";
+          t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension;
+          if (!f->anchor.isEmpty() && f->reversed) t << "#" << f->anchor;  
+          t << "\">";
           t << "<param name=\"Name\" value=\"" << level1 << "\">"
                "</OBJECT>\n";
         }
@@ -223,6 +251,7 @@ void HtmlHelpIndex::writeFields(QTextStream &t)
     }
     lastLevel1 = level1.copy();
   } 
+  if (level2Started) t << "  </UL>" << endl;
 }
 
 //----------------------------------------------------------------------------
@@ -353,6 +382,7 @@ void HtmlHelp::initialize()
   s_languageDict.insert("japanese-en", new QCString("0x411 Japanese"));
   s_languageDict.insert("korean",      new QCString("0x412 Korean"));
   s_languageDict.insert("chinese",     new QCString("0x804 Chinese (PRC)"));
+  s_languageDict.insert("chinese-traditional", new QCString("0x404 Chinese (Taiwan)"));
 }
 
 
@@ -528,7 +558,7 @@ void HtmlHelp::addContentsItem(bool isDir,
 void HtmlHelp::addIndexItem(const char *level1, const char *level2,
                             const char *ref, const char *anchor)
 {
-  index->addItem(level1,level2,ref,anchor,TRUE);
-  index->addItem(level2,level1,ref,anchor,FALSE);
+  index->addItem(level1,level2,ref,anchor,TRUE,FALSE);
+  index->addItem(level2,level1,ref,anchor,TRUE,TRUE);
 }
 
