@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: index.h,v 1.28 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,15 +26,15 @@ enum IndexSections
   isTitlePageStart,
   isTitlePageAuthor,
   isMainPage,
-//  isPackageIndex,
   isModuleIndex,
+  isDirIndex,
   isNamespaceIndex,
   isClassHierarchyIndex,
   isCompoundIndex,
   isFileIndex,
   isPageIndex,
-//  isPackageDocumentation,
   isModuleDocumentation,
+  isDirDocumentation,
   isNamespaceDocumentation,
   isClassDocumentation,
   isFileDocumentation,
@@ -49,23 +49,28 @@ void writeIndex(OutputList &ol);
 void writeHierarchicalIndex(OutputList &ol);
 void writeAlphabeticalIndex(OutputList &ol);
 void writeClassHierarchy(OutputList &ol);
-void writeFileIndex(OutputList &ol);
-void writeSourceIndex(OutputList &ol);
 void writeAnnotatedIndex(OutputList &ol);
 void writeAnnotatedClassList(OutputList &ol);
-void writeMemberIndex(OutputList &ol);
 void writeMemberList(OutputList &ol,bool useSections);
+
+void writeSourceIndex(OutputList &ol);
 void writeHeaderIndex(OutputList &ol);
 void writeHeaderFileList(OutputList &ol);
+
 void writeExampleIndex(OutputList &ol);
 void writePageIndex(OutputList &ol);
-void writeFileMemberIndex(OutputList &ol);
-void writeGroupIndex(OutputList &ol);
+void writeFileIndex(OutputList &ol);
 void writeNamespaceIndex(OutputList &ol);
+void writeGroupIndex(OutputList &ol);
+void writeDirIndex(OutputList &ol);
+void writePackageIndex(OutputList &ol);
+
+void writeClassMemberIndex(OutputList &ol);
+void writeFileMemberIndex(OutputList &ol);
 void writeNamespaceMemberIndex(OutputList &ol);
+
 void writeGraphicalClassHierarchy(OutputList &ol);
 void writeGraphInfo(OutputList &ol);
-void writePackageIndex(OutputList &ol);
 
 void countDataStructures();
 
@@ -74,6 +79,7 @@ enum HighlightedItem
   HLI_None=0,
   HLI_Main,
   HLI_Modules,
+  HLI_Directories,
   HLI_Namespaces,
   HLI_Hierarchy,
   HLI_Classes,
@@ -95,9 +101,9 @@ enum ClassMemberHighlight
   CMHL_Typedefs,
   CMHL_Enums,
   CMHL_EnumValues,
-  CMHL_Related,
   CMHL_Properties,
   CMHL_Events,
+  CMHL_Related,
   CMHL_Total = CMHL_Events+1
 };
 
@@ -124,6 +130,19 @@ enum NamespaceMemberHighlight
   NMHL_Total = FMHL_EnumValues+1
 };
 
+enum ClassHighlight
+{
+  CHL_All = 0,
+  CHL_Classes,
+  CHL_Structs,
+  CHL_Unions,
+  CHL_Interfaces,
+  CHL_Protocols,
+  CHL_Categories,
+  CHL_Exceptions,
+  CHL_Total = CHL_Exceptions+1
+};
+
 extern int annotatedClasses;
 extern int hierarchyClasses;
 extern int documentedFiles;
@@ -135,6 +154,7 @@ extern int documentedFileMembers[FMHL_Total];
 extern int documentedNamespaceMembers[NMHL_Total];
 extern int documentedHtmlFiles;
 extern int documentedPages;
+extern int documentedDirs;
 
 void startTitle(OutputList &ol,const char *fileName);
 void endTitle(OutputList &ol,const char *fileName,const char *name);
