@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -43,11 +43,14 @@
 #ifdef LANG_JP
 #include "translator_jp.h"
 #endif
+#ifdef LANG_JE
+#include "translator_je.h"
+#endif
 #ifdef LANG_ES
 #include "translator_es.h"
 #endif
 #ifdef LANG_FI
-#include "translator_fi.h"
+//#include "translator_fi.h"
 #endif
 #ifdef LANG_RU
 #include "translator_ru.h"
@@ -64,6 +67,9 @@
 #ifdef LANG_HU
 #include "translator_hu.h"
 #endif
+#ifdef LANG_KE
+#include "translator_ke.h"
+#endif
 #ifdef LANG_KR
 #include "translator_kr.h"
 #endif
@@ -76,6 +82,9 @@
 #ifdef LANG_CN
 #include "translator_cn.h"
 #endif
+#ifdef LANG_TW
+#include "translator_tw.h"
+#endif
 #ifdef LANG_NO
 #include "translator_no.h"
 #endif
@@ -94,15 +103,37 @@
 #ifdef LANG_GR
 #include "translator_gr.h"
 #endif
+#ifdef LANG_SR
+#include "translator_sr.h"
+#endif
+#ifdef LANG_CA
+#include "translator_ca.h"
+#endif
 //#ifdef LANG_JS
 //#include "translator_js.h"
 //#endif
+#ifdef LANG_LT
+#include "translator_lt.h"
+#endif
+#ifdef LANG_ZA
+#include "translator_za.h"
+#endif
 #endif
 
 #define L_EQUAL(a) !stricmp(langName,a)
 
 Translator *theTranslator=0;
 
+static const char obsoleteMsg[] =
+        "---------\n"
+        "ERROR: The selected language is no longer supported!\n"
+        "If you want doxygen to produce output in this language \n"
+        "you are kindly requested to help bringing the documentation \n"
+        "up to date. Please read the development section of the manual \n"
+        "for more information or contact Petr Prikryl (Prikryl@skil.cz).\n"
+        "Thanks in advance!\n"
+        "---------\n";
+
 bool setTranslator(const char *langName)
 {
   if (L_EQUAL("english"))
@@ -152,6 +183,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorJapanese;
   }
 #endif
+#ifdef LANG_JE
+  else if (L_EQUAL("japanese-en"))
+  {
+    theTranslator=new TranslatorJapaneseEn;
+  }
+#endif
 #ifdef LANG_ES
   else if (L_EQUAL("spanish"))
   {
@@ -161,7 +198,9 @@ bool setTranslator(const char *langName)
 #ifdef LANG_FI
   else if (L_EQUAL("finnish"))
   {
-    theTranslator=new TranslatorFinnish;
+    //theTranslator=new TranslatorFinnish;
+    theTranslator=new TranslatorEnglish;
+    err(obsoleteMsg);
   }
 #endif
 #ifdef LANG_RU
@@ -200,6 +239,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorKorean;
   }
 #endif
+#ifdef LANG_KE
+  else if (L_EQUAL("korean-en"))
+  {
+    theTranslator=new TranslatorKoreanEn;
+  }
+#endif
 #ifdef LANG_RO
   else if (L_EQUAL("romanian"))
   {
@@ -218,6 +263,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorChinese;
   }
 #endif
+#ifdef LANG_TW
+  else if (L_EQUAL("chinese-traditional"))
+  {
+    theTranslator=new TranslatorChinesetraditional;
+  }
+#endif
 #ifdef LANG_NO
   else if (L_EQUAL("norwegian"))
   {
@@ -254,11 +305,25 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorGreek;
   }
 #endif
-//  else if (L_EQUAL("japanese-sjis"))
-//  {
-//    theTranslator=new TranslatorJapaneseSjis;
-//  }
+#ifdef LANG_SR
+  else if (L_EQUAL("serbian"))
+  {
+    theTranslator=new TranslatorSerbian;
+  }
 #endif
+#ifdef LANG_CA
+  else if (L_EQUAL("catalan"))
+  {
+    theTranslator=new TranslatorCatalan;
+  }
+#endif
+#ifdef LANG_LT
+  else if (L_EQUAL("lithuanian"))
+  {
+    theTranslator=new TranslatorLithuanian;
+  }
+#endif
+#endif // ENGLISH_ONLY
   else // use the default language (i.e. english)
   {
     theTranslator=new TranslatorEnglish;
