@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -79,8 +79,10 @@ QString LatexDocVisitor::escapeMakeIndexChars(const char *s)
 }
 
 
-LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
-  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), m_insideItem(FALSE), m_hide(FALSE) 
+LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci,
+                                 bool insideTabbing) 
+  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), 
+    m_insideItem(FALSE), m_hide(FALSE), m_insideTabbing(insideTabbing) 
 {
 }
 
@@ -839,24 +841,24 @@ void LatexDocVisitor::visitPost(DocSecRefList *)
   m_t << "\\normalsize" << endl;
 }
 
-void LatexDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void LatexDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void LatexDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void LatexDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void LatexDocVisitor::visitPre(DocParamSect *s)
 {
@@ -907,14 +909,23 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
     m_t << "} ";
   }
   m_t << "{\\em ";
-  QStrListIterator li(pl->parameters());
-  const char *s;
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
   bool first=TRUE;
-  for (li.toFirst();(s=li.current());++li)
+  for (li.toFirst();(param=li.current());++li)
   {
     if (!first) m_t << ","; else first=FALSE;
     m_insideItem=TRUE;
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
     m_insideItem=FALSE;
   }
   m_t << "}]";
@@ -928,8 +939,9 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
   m_t << "\\begin{Desc}" << endl;
+  bool anonymousEnum = x->file()=="@";
   m_t << "\\item[";
-  if (Config_getBool("PDF_HYPERLINKS"))
+  if (Config_getBool("PDF_HYPERLINKS") && !anonymousEnum)
   {
     m_t << "\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
   }
@@ -979,7 +991,7 @@ void LatexDocVisitor::visitPost(DocText *)
 
 void LatexDocVisitor::filter(const char *str)
 { 
-  filterLatexString(m_t,str,FALSE,m_insidePre,m_insideItem);
+  filterLatexString(m_t,str,m_insideTabbing,m_insidePre,m_insideItem);
 }
 
 void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
