@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,7 +30,7 @@ class QString;
 class LatexDocVisitor : public DocVisitor
 {
   public:
-    LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci);
+    LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci,bool insideTabbing);
     
     //--------------------------------------
     // visitor functions for leaf nodes
@@ -111,8 +111,8 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocSecRefItem *);
     void visitPre(DocSecRefList *);
     void visitPost(DocSecRefList *);
-    void visitPre(DocLanguage *);
-    void visitPost(DocLanguage *);
+    //void visitPre(DocLanguage *);
+    //void visitPost(DocLanguage *);
     void visitPre(DocParamSect *);
     void visitPost(DocParamSect *);
     void visitPre(DocParamList *);
@@ -154,6 +154,7 @@ class LatexDocVisitor : public DocVisitor
     bool m_insidePre;
     bool m_insideItem;
     bool m_hide;
+    bool m_insideTabbing;
     QStack<bool> m_enabled;
 };
 
