@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -31,6 +31,7 @@
 #include "pagedef.h"
 #include "docparser.h"
 #include "latexdocvisitor.h"
+#include "dirdef.h"
 
 //static QCString filterTitle(const char *s)
 //{
@@ -101,38 +102,13 @@ LatexGenerator::LatexGenerator() : OutputGenerator()
   //printf("LatexGenerator::LatexGenerator() insideTabbing=FALSE\n");
   insideTabbing=FALSE;
   firstDescItem=TRUE;
-  insidePre=FALSE;
+  m_indent=0;
 }
 
 LatexGenerator::~LatexGenerator()
 {
 }
 
-//LatexGenerator::LatexGenerator(const LatexGenerator &g)
-//  : OutputGenerator(g)
-//{
-//  col=g.col;
-//}
-
-//void LatexGenerator::append(const OutputGenerator *g)
-//{
-//  t << g->getContents();
-//  col+=((LatexGenerator *)g)->col;
-//  insideTabbing=insideTabbing || ((LatexGenerator *)g)->insideTabbing;
-//  firstDescItem = ((LatexGenerator *)g)->firstDescItem;
-//  insidePre = insidePre || ((LatexGenerator *)g)->insidePre;
-//  //printf("LatexGenerator::append(%s) insideTabbing=%s\n", g->getContents().data(),
-//  //    insideTabbing ? "TRUE" : "FALSE" );
-//}
-
-//OutputGenerator *LatexGenerator::copy()
-//{
-//  LatexGenerator *result = new LatexGenerator;
-//  result->insideTabbing=insideTabbing;
-//  result->insidePre=insidePre;
-//  return result;
-//}
-
 void LatexGenerator::init()
 {
   QCString dir=Config_getString("LATEX_OUTPUT");
@@ -157,7 +133,7 @@ void LatexGenerator::init()
   QTextStream t(&file);
   if (!Config_getBool("USE_PDFLATEX")) // use plain old latex
   {
-    t << "all: refman.dvi" << endl
+    t << "all clean: refman.dvi" << endl
       << endl
       << "ps: refman.ps" << endl
       << endl
@@ -206,7 +182,7 @@ void LatexGenerator::init()
   }
   else // use pdflatex for higher quality output
   {
-    t << "all: refman.pdf" << endl << endl;
+    t << "all clean: refman.pdf" << endl << endl;
     t << "refman.pdf: refman.tex" << endl;
     t << "\tpdflatex refman.tex" << endl;
     t << "\tmakeindex refman.idx" << endl;
@@ -432,12 +408,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -501,6 +477,10 @@ void LatexGenerator::startIndexSection(IndexSections is)
       if (compactLatex) t << "\\section"; else t << "\\chapter";
       t << "{"; //Module Index}\n"
       break;
+    case isDirIndex:
+      if (compactLatex) t << "\\section"; else t << "\\chapter";
+      t << "{"; //Directory Index}\n"
+      break;
     case isNamespaceIndex:
       if (compactLatex) t << "\\section"; else t << "\\chapter";
       t << "{"; //Namespace Index}\"
@@ -537,6 +517,22 @@ void LatexGenerator::startIndexSection(IndexSections is)
         }
       }
       break;
+    case isDirDocumentation:
+      {
+        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        DirDef *dd;
+        bool found=FALSE;
+        for (dli.toFirst();(dd=dli.current()) && !found;++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            if (compactLatex) t << "\\section"; else t << "\\chapter";
+            t << "{"; //Module Documentation}\n";
+            found=TRUE;
+          }
+        }
+      }
+      break;
     case isNamespaceDocumentation:
       {
         NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
@@ -637,6 +633,9 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isModuleIndex:
       t << "}\n\\input{modules}\n";
       break;
+    case isDirIndex:
+      t << "}\n\\input{dirs}\n";
+      break;
     case isNamespaceIndex:
       t << "}\n\\input{namespaces}\n";
       break;
@@ -675,6 +674,29 @@ void LatexGenerator::endIndexSection(IndexSections is)
         }
       }
       break;
+    case isDirDocumentation:
+      {
+        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        DirDef *dd;
+        bool found=FALSE;
+        for (dli.toFirst();(dd=dli.current()) && !found;++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            t << "}\n\\input{" << dd->getOutputFileBase() << "}\n";
+            found=TRUE;
+          }
+        }
+        for (;(dd=dli.current());++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "{" << dd->getOutputFileBase() << "}\n";
+          }
+        }
+      }
+      break;
     case isNamespaceDocumentation:
       {
         NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
@@ -806,14 +828,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -1212,7 +1234,7 @@ void LatexGenerator::endSection(const char *lab,SectionInfo::SectionType)
 //void LatexGenerator::docifyStatic(QTextStream &t,const char *str)
 void LatexGenerator::docify(const char *str)
 {
-  filterLatexString(t,str,insideTabbing,insidePre);
+  filterLatexString(t,str,insideTabbing,FALSE);
 }
 
 void LatexGenerator::codify(const char *str)
@@ -1321,12 +1343,42 @@ void LatexGenerator::endMemberItem()
   t << endl; 
 }
 
+void LatexGenerator::startMemberDescription() 
+{
+  if (!insideTabbing)
+  { 
+    t << "\\begin{CompactList}\\small\\item\\em "; 
+  }
+  else
+  {
+    for (int i=0;i<m_indent+1;i++) t << "\\>";
+    t << "{\\em ";
+  }
+}
+
+void LatexGenerator::endMemberDescription() 
+{ 
+  if (!insideTabbing)
+  {
+    t << "\\item\\end{CompactList}"; 
+  }
+  else
+  {
+    t << "}\\\\";
+    m_indent=0;
+  }
+}
+
+
 void LatexGenerator::writeNonBreakableSpace(int) 
 {
   if (insideTabbing)
+  {
     t << "\\>";
+    m_indent++;
+  }
   else
-    t << "\\ "; 
+    t << "~"; 
 }
 
 void LatexGenerator::startMemberList()  
@@ -1396,6 +1448,15 @@ void LatexGenerator::endInclDepGraph(DotInclDepGraph &g)
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
 
+void LatexGenerator::startGroupCollaboration() 
+{
+}
+
+void LatexGenerator::endGroupCollaboration(DotGroupCollaboration &g) 
+{
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+}
+
 void LatexGenerator::startCallGraph() 
 {
 }
@@ -1405,6 +1466,15 @@ void LatexGenerator::endCallGraph(DotCallGraph &g)
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
 
+void LatexGenerator::startDirDepGraph() 
+{
+}
+
+void LatexGenerator::endDirDepGraph(DotDirDeps &g) 
+{
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+}
+
 void LatexGenerator::startDescription() 
 { 
   t << "\\begin{description}" << endl; 
@@ -1470,7 +1540,7 @@ void LatexGenerator::endParamList()
 
 void LatexGenerator::printDoc(DocNode *n)
 {
-  LatexDocVisitor *visitor = new LatexDocVisitor(t,*this);
+  LatexDocVisitor *visitor = new LatexDocVisitor(t,*this,insideTabbing);
   n->accept(visitor);
   delete visitor; 
 }
