@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlgen.cpp,v 1.17 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -632,5 +632,6 @@ void ManGenerator::printDoc(DocNode *n)
   n->accept(visitor);
   delete visitor; 
   firstCol=FALSE;
+  paragraph = FALSE;
 }
 
