@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlgen.h,v 1.15 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -31,7 +31,8 @@ class ManGenerator : public OutputGenerator
     //OutputGenerator *copy()  { return new ManGenerator; } 
     //OutputGenerator *clone() { return new ManGenerator(*this); }
     //void append(const OutputGenerator *o);
-    void enable() { active=TRUE; }
+    void enable() 
+    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
     void enableIf(OutputType o)  { if (o==Man) active=TRUE;  }
     void disableIf(OutputType o) { if (o==Man) active=FALSE; }
@@ -93,7 +94,7 @@ class ManGenerator : public OutputGenerator
     void endMemberSections() {}
     void startMemberHeader();
     void endMemberHeader();
-    void insertMemberAlign() {}
+    void insertMemberAlign(bool) {}
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
     void writeListItem();
@@ -103,6 +104,8 @@ class ManGenerator : public OutputGenerator
     void endAnonTypeScope(int);
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams() {}
+    void endMemberTemplateParams() {}
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -227,12 +230,16 @@ class ManGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &) {}
     void startInclDepGraph() {}
     void endInclDepGraph(DotInclDepGraph &) {}
+    void startGroupCollaboration() {}
+    void endGroupCollaboration(DotGroupCollaboration &) {}
     void startCallGraph() {}
     void endCallGraph(DotCallGraph &) {}
+    void startDirDepGraph() {} 
+    void endDirDepGraph(DotDirDeps &) {}
     void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem() {}
