@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: memberlist.h,v 1.19 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -54,10 +54,13 @@ class MemberList : public QList<MemberDef>
                const char *title,const char *subtitle);
     void writeDocumentation(OutputList &ol,const char *scopeName,
                Definition *container,const char *title);
+    void writeDocumentationPage(OutputList &ol,
+               const char *scopeName, Definition *container);
     void addMemberGroup(MemberGroup *mg);
     void setInGroup(bool group) { m_inGroup=group; }
     void addListReferences(Definition *def);
     void findSectionsInDocumentation();
+    MemberGroupList *getMemberGroupList() const { return memberGroupList; }
 
   private:
     int m_varCnt,m_funcCnt,m_enumCnt,m_enumValCnt,m_typeCnt;
