@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: namespacedef.cpp,v 1.27 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,19 +29,28 @@
 #include "searchindex.h"
 
 NamespaceDef::NamespaceDef(const char *df,int dl,
-                           const char *name,const char *lref) : 
+                           const char *name,const char *lref,
+                           const char *fName) : 
    Definition(df,dl,name)
 {
-  fileName="namespace";
-  fileName+=name;
+  if (fName)
+  {
+    fileName = stripExtension(fName);
+  }
+  else
+  {
+    fileName="namespace";
+    fileName+=name;
+  }
   classSDict = new ClassSDict(17);
   namespaceSDict = new NamespaceSDict(17);
-  m_innerCompounds = new SDict<Definition>(257);
+  m_innerCompounds = new SDict<Definition>(17);
   usingDirList = 0;
   usingDeclList = 0;
   setReference(lref);
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
+  visited=FALSE;
 }
 
 NamespaceDef::~NamespaceDef()
@@ -264,25 +273,29 @@ void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
   
 void NamespaceDef::writeDocumentation(OutputList &ol)
 {
-  QCString pageTitle=displayName()+" Namespace Reference";
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
-  startTitle(ol,getOutputFileBase());
-  //ol.docify(pageTitle);
+  QCString pageTitle;
   if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
   {
-    ol.parseText(theTranslator->trPackage(displayName()));
+    pageTitle = theTranslator->trPackage(displayName());
   }
   else
   {
-    ol.parseText(theTranslator->trNamespaceReference(displayName()));
+    pageTitle = theTranslator->trNamespaceReference(displayName());
   }
+  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
+  startTitle(ol,getOutputFileBase());
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),displayName());
   
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
@@ -321,7 +334,9 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   ol.endTextBlock();
   
   ol.startMemberSections();
-  classSDict->writeDeclaration(ol);
+  classSDict->writeDeclaration(ol,0,0,TRUE);
+
+  namespaceSDict->writeDeclaration(ol,TRUE);
 
   /* write user defined member groups */
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -345,6 +360,39 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
     writeDetailedDocumentation(ol);
   }
 
+  writeMemberDocumentation(ol);
+
+  // write Author section (Man only)
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Man);
+  ol.startGroupHeader();
+  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
+  ol.endGroupHeader();
+  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+
+  ol.popGeneratorState();
+  endFile(ol);
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    allMemberList.sort();
+    writeMemberPages(ol);
+  }
+}
+
+void NamespaceDef::writeMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
+  
   docDefineMembers.writeDocumentation(ol,name(),this,
                           theTranslator->trDefineDocumentation());
   
@@ -363,22 +411,61 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   docVarMembers.writeDocumentation(ol,name(),this,
                           theTranslator->trVariableDocumentation());
 
-  // write Author section (Man only)
-  ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Man);
-  ol.startGroupHeader();
-  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
-  ol.endGroupHeader();
-  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
-
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
+    ol.enable(OutputGenerator::Html);
   }
+}
+
+void NamespaceDef::writeMemberPages(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+
+  docDefineMembers.writeDocumentationPage(ol,name(),this);
+  docProtoMembers.writeDocumentationPage(ol,name(),this);
+  docTypedefMembers.writeDocumentationPage(ol,name(),this);
+  docEnumMembers.writeDocumentationPage(ol,name(),this);
+  docFuncMembers.writeDocumentationPage(ol,name(),this);
+  docVarMembers.writeDocumentationPage(ol,name(),this);
 
   ol.popGeneratorState();
-  endFile(ol);
+}
+
+void NamespaceDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberListIterator mli(allMemberList);
+  MemberDef *md;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    if (md->getNamespaceDef()==this && md->isLinkable())
+    {
+      ol.writeString("          <tr><td class=\"navtab\">");
+      if (md->isLinkableInProject())
+      {
+        if (md==currentMd) // selected item => highlight
+        {
+          ol.writeString("<a class=\"qindexHL\" ");
+        }
+        else
+        {
+          ol.writeString("<a class=\"qindex\" ");
+        }
+        ol.writeString("href=\"");
+        ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+        ol.writeString("\">");
+        ol.writeString(md->localName());
+        ol.writeString("</a>");
+      }
+      ol.writeString("</td></tr>\n");
+    }
+  }
+
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
 }
 
 int NamespaceDef::countMembers()
@@ -413,7 +500,14 @@ void NamespaceDef::addUsingDeclaration(Definition *d)
 
 QCString NamespaceDef::getOutputFileBase() const 
 { 
-  return convertNameToFile(fileName); 
+  if (isReference())
+  {
+    return fileName;
+  }
+  else
+  {
+    return convertNameToFile(fileName); 
+  }
 }
 
 Definition *NamespaceDef::findInnerCompound(const char *n)
@@ -492,3 +586,70 @@ void NamespaceDef::combineUsingRelations()
   }
 }
 
+void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
+{
+  if (count()==0) return; // no namespaces in the list
+
+  SDict<NamespaceDef>::Iterator ni(*this);
+  NamespaceDef *nd;
+  bool found=FALSE;
+  for (ni.toFirst();(nd=ni.current()) && !found;++ni)
+  {
+    if (nd->isLinkable()) found=TRUE;
+  }
+  if (!found) return; // no linkable namespaces in the list
+
+  // write list of namespaces
+  ol.startMemberHeader();
+  bool javaOpt = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+  if (javaOpt)
+  {
+    ol.parseText(theTranslator->trPackages());
+  }
+  else
+  {
+    ol.parseText(theTranslator->trNamespaces());
+  }
+  ol.endMemberHeader();
+  ol.startMemberList();
+  for (ni.toFirst();(nd=ni.current());++ni)
+  {
+    if (nd->isLinkable())
+    {
+      ol.startMemberItem(0);
+      if (javaOpt)
+      {
+        ol.docify("package ");
+      }
+      else
+      {
+        ol.docify("namespace ");
+      }
+      ol.insertMemberAlign();
+      QCString name;
+      if (localName)
+      {
+        name = nd->localName();
+      }
+      else
+      {
+        name = nd->displayName();
+      }
+      ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,name);
+      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+      {
+        Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
+      }
+      ol.endMemberItem();
+      if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+      {
+        ol.startMemberDescription();
+        ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
+        ol.endMemberDescription();
+        ol.newParagraph();
+      }
+    }
+  }
+  ol.endMemberList();
+}
+
