@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: outputlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -132,7 +132,8 @@ void OutputList::popGeneratorState()
 void OutputList::parseDoc(const char *fileName,int startLine,
                   Definition *ctx,MemberDef * md,
                   const QCString &docStr,bool indexWords,
-                  bool isExample,const char *exampleName)
+                  bool isExample,const char *exampleName,
+                  bool singleLine,bool linkFromIndex)
 {
   int count=0;
   if (docStr.isEmpty()) return;
@@ -149,12 +150,14 @@ void OutputList::parseDoc(const char *fileName,int startLine,
   if (docStr.at(docStr.length()-1)=='\n')
   {
     root = validatingParseDoc(fileName,startLine,
-                              ctx,md,docStr,indexWords,isExample,exampleName);
+                              ctx,md,docStr,indexWords,isExample,exampleName,
+                              singleLine,linkFromIndex);
   }
   else
   {
     root = validatingParseDoc(fileName,startLine,
-                              ctx,md,docStr+"\n",indexWords,isExample,exampleName);
+                              ctx,md,docStr+"\n",indexWords,isExample,exampleName,
+                              singleLine,linkFromIndex);
   }
 
   og=outputs->first();
@@ -263,13 +266,14 @@ FORALL1(int a1,a1)
 FORALL1(DotClassGraph &a1,a1)
 FORALL1(DotInclDepGraph &a1,a1)
 FORALL1(DotCallGraph &a1,a1)
+FORALL1(DotDirDeps &a1,a1)
 FORALL1(DotGfxHierarchyTable &a1,a1)
+FORALL1(DotGroupCollaboration &a1,a1)
 FORALL1(SectionTypes a1,a1)
 #if defined(HAS_BOOL_TYPE) || defined(Q_HAS_BOOL_TYPE)
 FORALL1(bool a1,a1)
 FORALL2(bool a1,int a2,a1,a2)
 FORALL2(bool a1,bool a2,a1,a2)
-FORALL3(bool a1,bool a2,bool a3,a1,a2,a3)
 FORALL4(const char *a1,const char *a2,const char *a3,bool a4,a1,a2,a3,a4)
 #endif
 FORALL2(int a1,bool a2,a1,a2)
@@ -280,6 +284,7 @@ FORALL1(IndexSections a1,a1)
 FORALL2(const char *a1,const char *a2,a1,a2)
 FORALL2(const char *a1,bool a2,a1,a2)
 FORALL2(const char *a1,SectionInfo::SectionType a2,a1,a2)
+FORALL3(bool a1,bool a2,bool a3,a1,a2,a3)
 FORALL3(ClassDiagram &a1,const char *a2,const char *a3,a1,a2,a3)
 FORALL3(const char *a1,const char *a2,const char *a3,a1,a2,a3)
 FORALL3(const char *a1,const char *a2,bool a3,a1,a2,a3)
