@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,7 +34,8 @@ class RTFGenerator : public OutputGenerator
     //OutputGenerator *copy();
     //OutputGenerator *clone() { return new RTFGenerator(*this); }
     //void append(const OutputGenerator *o);
-    void enable() { active=TRUE; }
+    void enable() 
+    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
     void enableIf(OutputType o)  { if (o==RTF) active=TRUE;  }
     void disableIf(OutputType o) { if (o==RTF) active=FALSE; }
@@ -106,9 +107,11 @@ class RTFGenerator : public OutputGenerator
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams() {}
+    void endMemberTemplateParams() {}
     //void memberGroupSpacing(bool) {}
     //void memberGroupSeparator() {}
-    void insertMemberAlign() {}
+    void insertMemberAlign(bool) {}
 
     void writeRuler() { rtfwriteRuler_thin(); }
 	
@@ -223,8 +226,12 @@ class RTFGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &);
     void startInclDepGraph();
     void endInclDepGraph(DotInclDepGraph &);
+    void startGroupCollaboration();
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
     void endCallGraph(DotCallGraph &);
+    void startDirDepGraph();
+    void endDirDepGraph(DotDirDeps &g);
     void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startMemberGroupHeader(bool);
@@ -235,7 +242,7 @@ class RTFGenerator : public OutputGenerator
     void endMemberGroup(bool);
     
     void startTextBlock(bool dense);
-    void endTextBlock();
+    void endTextBlock(bool);
     void lastIndexPage();
 
     void startMemberDocPrefixItem() {}
@@ -287,10 +294,10 @@ class RTFGenerator : public OutputGenerator
     void beginRTFDocument();
     void beginRTFChapter();
     void beginRTFSection();
-    void rtfwriteRuler_doubleline() { t << "{\\pard\\widctlpar\\brdrb\\brdrdb\\brdrw15\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_emboss() { t << "{\\pard\\widctlpar\\brdrb\\brdremboss\\brdrw15\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_thick() { t << "{\\pard\\widctlpar\\brdrb\\brdrs\\brdrw75\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_thin() { t << "{\\pard\\widctlpar\\brdrb\\brdrs\\brdrw5\\brsp20 \\adjustright \\par}" << endl; };
+    void rtfwriteRuler_doubleline();
+    void rtfwriteRuler_emboss();
+    void rtfwriteRuler_thick();
+    void rtfwriteRuler_thin();
     void writeRTFReference(const char *label);
     char *getMultiByte(int c);
 };
