@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: scanner.h,v 1.15 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,6 +23,13 @@
 class OutputList;
 class Entry;
 
-extern void parseMain(Entry *);
+// Public interface provided by the language scanner
+void parseMain(Entry *);
+void parseMain(Entry *,const char *fileName);
+
+// Internal callback interface for comment block scanner
+void parsePrototype(const QCString &text);
+void handleGroupStartCommand(const char *header);
+void handleGroupEndCommand();
 
 #endif
