@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: sortdict.h,v 1.3 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -59,6 +59,14 @@ const uint SDict_primes[] =
   5516827,
   8826919,
   14123059,
+  23538433,
+  39230771,
+  65384537,
+  108974231,
+  181623707,
+  302706181,
+  504510283,
+  840850487,
   0xffffffff
 };
 #endif
@@ -234,7 +242,7 @@ class SDict
     
     /*! Returns the number of items stored in the dictionary
      */
-    int count()
+    int count() const
     {
       return m_list->count();
     }
