@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -14,7 +14,7 @@
  * input used in their production; they are not affected by this license.
  *
 */
-// translation by Boris Bralo <boris.bralo@zg.tel.hr>
+// translation by Boris Bralo <boris.bralo@zg.htnet.hr>
 // Updates:
 // --------
 // 2000/08/20 
@@ -46,6 +46,25 @@
 //
 // 2001/11/13
 // - Added strings for 1.2.13
+//
+// 2003/02/26
+// - Added strings for 1.2.18
+//
+// 2003/04/29
+// - Added strings for 1.3.0
+//
+// 2004/06/21
+// - Added strings for 1.3.8
+//
+// 2004/09/15
+// - Added strings for 1.3.9
+//
+// 2005/02/28
+// - Removed obsolete (unused) methods
+//
+// 2005/03/21
+// - Added strings for 1.4.1
+//
 
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
@@ -56,22 +75,30 @@ class TranslatorCroatian : public Translator
         /*! to avoid macro redefinition from translator_cz.h */
         inline QCString decode(const QCString& sInput)
         { 
-#ifdef _WIN32
-                return ISO88592ToWin1250(sInput);
-#else
-                return sInput;
-#endif
+          if (Config_getBool("USE_WINDOWS_ENCODING"))
+          {
+            return ISO88592ToWin1250(sInput);
+          }
+          else
+          {
+            return sInput;
+          }
         }
   
   public:
     QCString idLanguage()
     { return "croatian"; }
     QCString idLanguageCharset()
-#ifdef _WIN32
-        { return "windows-1250"; }
-#else
-        { return "iso-8859-2"; }
-#endif
+    {
+      if (Config_getBool("USE_WINDOWS_ENCODING"))
+      {
+        return "windows-1250"; 
+      }
+      else
+      {
+        return "iso-8859-2";
+      }
+    }
     QCString latexLanguageSupportCommand()
     { return "\\usepackage[croatian]{babel}\n"; }
     QCString trRelatedFunctions()
@@ -84,10 +111,8 @@ class TranslatorCroatian : public Translator
     { return decode("Dokumentacija typedef lanova"); }
     QCString trMemberEnumerationDocumentation()
     { return decode("Dokumentacija enumeracijskih lanova"); }
-    QCString trEnumerationValueDocumentation()
-    { return "Dokumentacija enumeracijskih vrijednosti"; }
     QCString trMemberFunctionDocumentation()
-        { return "Dokumentacija funkcija"; }
+    { return "Dokumentacija funkcija"; }
     QCString trMemberDataDocumentation()
     { return "Documentacija varijabli"; }
     QCString trMore()
@@ -129,8 +154,6 @@ class TranslatorCroatian : public Translator
 	}
     QCString trFileList()
     { return "Popis datoteka"; }
-    QCString trHeaderFiles()
-    { return "Header datoteke"; }
     QCString trCompoundMembers()
 	{
 		if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
@@ -172,7 +195,7 @@ class TranslatorCroatian : public Translator
 	  else
 		  result+="lanova struktura s linkovima na ";
 		  
-      if (extractAll)
+      if (!extractAll)
 	  {
 		  result+="dokumentaciju svakog lana:";
       }
@@ -197,16 +220,12 @@ class TranslatorCroatian : public Translator
 		  result+="datoteke u kojima se nalaze:";
       return decode(result);
     }
-    QCString trHeaderFilesDescription()
-    { return decode("Popis header datoteka koje ine API :"); }
     QCString trExamplesDescription()
     { return "Popis primjera :"; }
     QCString trRelatedPagesDescription()
     { return "Popis povezanih stranica:"; }
     QCString trModulesDescription()
     { return "Popis svih modula:"; }
-    QCString trNoDescriptionAvailable()
-    { return "Opis nije dostupan"; }
 
     QCString trDocumentation()
     { return "Dokumentacija"; }
@@ -294,14 +313,8 @@ class TranslatorCroatian : public Translator
     }
     QCString trForInternalUseOnly()
     { return decode("Iskljuivo za internu uporabu."); }
-    QCString trReimplementedForInternalReasons()
-        { return decode("Reimplementirano zbog internih razloga; "
-                                        "Nema utjecaja na API."); 
-    }
     QCString trWarning()
     { return "Upozorenje"; }
-    QCString trBugsAndLimitations()
-    { return decode("Greke i ogranienja"); }
     QCString trVersion()
     { return "Verzija"; }
     QCString trDate()
@@ -356,6 +369,8 @@ class TranslatorCroatian : public Translator
         case ClassDef::Struct: result+=" strukture "; break;
         case ClassDef::Union:  result+=" unije "; break;
         case ClassDef::Interface:  result+=" suelja (interface) "; break;
+        case ClassDef::Protocol:   result+=" protocol "; break; // translate me!
+        case ClassDef::Category:   result+=" category "; break; // translate me!
         case ClassDef::Exception:  result+=" iznimke (exception) "; break;
       }
           result += clName;
@@ -504,6 +519,8 @@ class TranslatorCroatian : public Translator
         case ClassDef::Struct:     result+="strukture"; break;
         case ClassDef::Union:      result+="unije"; break;
         case ClassDef::Interface:  result+="suelja (interface)"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="iznimke (exception)"; break;
       }
       result+=" je generirana iz " + trFile(FALSE, single) + ": ";
@@ -539,10 +556,6 @@ class TranslatorCroatian : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Izvorne datoteke";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definirano u liniji @0 datoteke @1.";
@@ -828,11 +841,6 @@ class TranslatorCroatian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("Suelja (interfaces)");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -858,11 +866,6 @@ class TranslatorCroatian : public Translator
     {
       return "Paketi";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Dokumentacija paketa";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -972,17 +975,6 @@ class TranslatorCroatian : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Polj" : "polj"));
-      result+= (singular ? "e" : "a");
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1040,6 +1032,230 @@ class TranslatorCroatian : public Translator
     {
       return "Implementirano u "+trWriteList(numEntries)+".";
     }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return decode("Sadraj");
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Popis zastarjelih metoda";
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return decode("Dogaaji");
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return decode("Dokumentacija dogaaja");
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return "Tipovi u paketu";
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "Funkcije u paketu";
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return decode("Statike funkcije u paketu");
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return "Atributi u paketu";
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return decode("Statiki atributi u paketu");
+    }
+	//////////////////////////////////////////////////////////////////////////
+	// new since 1.3.1
+	//////////////////////////////////////////////////////////////////////////
+
+	/*! Used in the quick index of a class/file/namespace member list page 
+	*  to link to the unfiltered list of all members.
+	*/
+	virtual QCString trAll()
+	{
+		return "Sve";
+	}
+	/*! Put in front of the call graph for a function. */
+	virtual QCString trCallGraph()
+	{
+		return "Ovo je dijagram poziva za ovu funkciju:";
+	}
+
+	//////////////////////////////////////////////////////////////////////////
+	// new since 1.3.3
+	//////////////////////////////////////////////////////////////////////////
+
+	/*! When the search engine is enabled this text is put in the header 
+	*  of each page before the field where one can enter the text to search 
+	*  for. 
+	*/
+	virtual QCString trSearchForIndex()
+	{
+		return decode("Trai");
+	}
+	/*! This string is used as the title for the page listing the search
+	*  results.
+	*/
+	virtual QCString trSearchResultsTitle()
+	{
+		return "Rezultati pretrage";
+	}
+	/*! This string is put just before listing the search results. The
+	*  text can be different depending on the number of documents found.
+	*  Inside the text you can put the special marker $num to insert
+	*  the number representing the actual number of search results.
+	*  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+	*  value 2 represents 2 or more matches. HTML markup is allowed inside
+	*  the returned string.
+	*/
+	virtual QCString trSearchResults(int numDocuments)
+	{
+		if (numDocuments==0)
+		{
+			return decode("Nema dokumenta koji odgovaraju vaem upitu");
+		}
+		else if (numDocuments==1)
+		{
+			return decode("Naen <b>1</b> dokument koji odgovara vaem upitu.");
+		}
+		else if (numDocuments<5) 
+		{
+			// croatian handle numbers up to 5 differently 
+			// For those of you who like to read comments :
+			// There are only 4 men in the world in croatian.
+			// We say 1 ovjek (man), 2 ovjeka, 3 ovjeka , 4 ovjeka , but 5, 6, 7 ... ljudi (people)
+			// That's deep, isn't it :-)?
+			return decode("Naena <b>$num</b> dokumenta koji odgovaraju vaem upitu."
+				"Najbolji su prikazani prvi.");
+		}
+		else 
+		{
+			return decode("Naeno <b>$num</b> dokumenata koji odgovaraju vaem upitu."
+				"Najbolji su prikazani prvi.");
+		}
+	}
+	/*! This string is put before the list of matched words, for each search 
+	*  result. What follows is the list of words that matched the query.
+	*/
+	virtual QCString trSearchMatches()
+	{
+		return decode("Pronaeno:");
+	}
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "Izvorni kod datoteke " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Stablo direktorija"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Dokumentacija direktorija"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Direktoriji"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Stablo direktorija sortirano abecednim redom:"; }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result= "Opis direktorija "; result += dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Direktorij" : "direktorij"));
+      if (!singular) result+="i"; 
+      return result; 
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode("Ovo je preoptereena funkcija (overload). "
+              "Razlikuje se od navedene metode "
+              "samo po vrsti argumenata koje prihvata.");
+    }
+
 };
 
 #endif
+
+
