@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2000 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,9 +18,7 @@
  *
  * Nickolay Semyonov
  * Andrey V. Stolyarov released Feb 14, 2001
- * Alexandr V. Chelpanov <cav@cryptopro.ru> released Apr 21, 2001
- *
- *          email (. )
+ * Alexandr V. Chelpanov <cav@cryptopro.ru> released Sep 25, 2004
  *
  *     list  documentation .
  *
@@ -44,7 +42,8 @@
  *
  *   ??  .
  *
- * : Vitaly A. Repin <vitaly@radio.hop.stu.neva.ru>
+ * : Vitaly A. Repin <vitaly@radio.hop.stu.neva.ru>,
+ *      <bbman@mail.ru>
  */
 
 #ifndef TRANSLATOR_RU_H
@@ -53,16 +52,19 @@
 class TranslatorRussian : public Translator
 {
   private:
-    /*! The Decode() inline assumes the source written in the 
+    /*! The decode() inline assumes the source written in the 
         Koi8-R encoding (maintainer dependent). 
      */
     inline QCString decode(const QCString & sInput)
     { 
-#ifdef _WIN32
-      return Koi8RToWindows1251(sInput);
-#else
-      return sInput;
-#endif
+      if (Config_getBool("USE_WINDOWS_ENCODING"))
+      {
+        return Koi8RToWindows1251(sInput);
+      }
+      else
+      {
+        return sInput;
+      }
     }
 
   public:
@@ -72,19 +74,29 @@ class TranslatorRussian : public Translator
 
     /* Used to get the command(s) for the language support. */
     virtual QCString latexLanguageSupportCommand()
-#ifdef _WIN32
-    { return "\\usepackage[cp1251]{inputenc}\n\\usepackage[russian]{babel}\n"; }
-#else
-    { return "\\usepackage[koi8-r]{inputenc}\n\\usepackage[russian]{babel}\n"; }
-#endif
+    {
+      if (Config_getBool("USE_WINDOWS_ENCODING"))
+      { 
+        return "\\usepackage[cp1251]{inputenc}\n\\usepackage[russian]{babel}\n"; 
+      }
+      else
+      { 
+        return "\\usepackage[koi8-r]{inputenc}\n\\usepackage[russian]{babel}\n"; 
+      }
+    }
 
     /*! return the language charset. This will be used for the HTML output */
     virtual QCString idLanguageCharset()
-#ifdef _WIN32
-    { return "Windows-1251"; }
-#else
-    { return "koi8-r"; }
-#endif
+    {
+      if (Config_getBool("USE_WINDOWS_ENCODING"))
+      { 
+        return "Windows-1251"; 
+      }
+      else
+      { 
+        return "koi8-r"; 
+      }
+    }
 
     // --- Language translation methods -------------------
 
@@ -204,10 +216,6 @@ class TranslatorRussian : public Translator
     virtual QCString trFileList()
     { return decode(""); }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return decode(" "); }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -225,7 +233,7 @@ class TranslatorRussian : public Translator
     /*??*/
     virtual QCString trFileMembers()
     {
-      return decode( " " );
+      return decode( "   " );
     }
 
     /*! This is put above each page as a link to all related pages. */
@@ -277,7 +285,7 @@ class TranslatorRussian : public Translator
           result+="      ";
         else
           result+="     ";
-        if(extractAll)
+        if(!extractAll)
         {
           if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
             result+="     .";
@@ -318,10 +326,6 @@ class TranslatorRussian : public Translator
       return decode( result );
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return decode("   ."); }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return decode("  ."); }
@@ -334,12 +338,6 @@ class TranslatorRussian : public Translator
     virtual QCString trModulesDescription()
     { return decode("  ."); }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return decode(" "); }
-
     // index titles (the project name is prepended for these) 
 
 
@@ -489,12 +487,6 @@ class TranslatorRussian : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return decode(""); }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return decode(" "); }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -554,20 +546,10 @@ class TranslatorRussian : public Translator
     virtual QCString trForInternalUseOnly()
     { return decode("   "); }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    /*??*/
-    { return decode("   "); 
-    }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return decode(""); }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return decode("  "); }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return decode(""); }
@@ -627,7 +609,7 @@ class TranslatorRussian : public Translator
      * related classes 
      */
     virtual QCString trRelatedFunctionDocumentation()
-    { return decode("      "
+    { return decode("     , "
         "  "); }
     
 //////////////////////////////////////////////////////////////////////////
@@ -649,6 +631,8 @@ class TranslatorRussian : public Translator
           case ClassDef::Struct: result+=""; break;
           case ClassDef::Union:  result+=""; break;
           case ClassDef::Interface:  result+=""; break;
+          case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+          case ClassDef::Category:   result+="category"; break; // translate me!
           case ClassDef::Exception:  result+=""; break;
         }
       }
@@ -660,6 +644,8 @@ class TranslatorRussian : public Translator
           case ClassDef::Struct: result+=""; break;
           case ClassDef::Union:  result+=""; break;
           case ClassDef::Interface:  result+=""; break;
+          case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+          case ClassDef::Category:   result+="category"; break; // translate me!
           case ClassDef::Exception:  result+=""; break;
         }
       }
@@ -823,6 +809,10 @@ class TranslatorRussian : public Translator
         case ClassDef::Interface:  result+="";
           if (single) result+=''; else result+="";
           break;
+        case ClassDef::Protocol:  result+="Protocol"; // translate me!
+          break;
+        case ClassDef::Category:  result+="Category"; // translate me!
+          break;
         case ClassDef::Exception:  result+="";
           if (single) result+=''; else result+='';
           break;
@@ -861,10 +851,6 @@ class TranslatorRussian : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return decode(" .");
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return decode(".    @1  @0");
@@ -1109,10 +1095,10 @@ class TranslatorRussian : public Translator
         "</ul>\n"
         "   :\n"
         "<ul>\n"
-        "<li>        "
+        "<li>-        "
         "  .\n"
-        "<li>     .\n"
-        "<li>     .\n"
+        "<li>-     .\n"
+        "<li>-     .\n"
         "<li>  ,    "
         "     ."
         "   , "
@@ -1172,11 +1158,6 @@ class TranslatorRussian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1209,11 +1190,6 @@ class TranslatorRussian : public Translator
     {
       return decode("");
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return decode("");
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1328,17 +1304,6 @@ class TranslatorRussian : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "" : ""));
-      result+=(singular ? "" : "");
-      return decode(result); 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1394,6 +1359,222 @@ class TranslatorRussian : public Translator
       return decode("  ")+trWriteList(numEntries)+".";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return decode("");
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return decode( "    " );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return decode( "" );
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return decode( "C" );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return decode( "    " );
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return decode( "    " );
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return decode( "     " );
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return decode( "    " );
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return decode( "     " );
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return decode( "" );
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return decode( " :" );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return decode( "" );
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return decode( " " );
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return decode( " ,      ." );
+      }
+      else if( numDocuments == 1 )
+      {
+        return decode( " 1 ." );
+      }
+      else 
+      {
+        return decode( "() <b>$num</b> (). "
+          "   ." );
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return decode( ":" );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return decode( "  " + filename );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode( " " ); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode( "" ); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode( "  " ); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return decode( " " ); }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=QCString("  ")+ dirName; return decode( result ); }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "" : ""));
+      if (singular) result+=""; else result+="";
+      return decode( result ); 
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode( "      "
+              "  .     "
+              "  ." );
+    }
 };
 
 #endif
