@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -104,6 +104,7 @@ bool getDefs(const QCString &scopeName,
                     bool checkCV=FALSE
                    );
 
+QCString getFileFilter(const char* name);
 
 bool resolveRef(/* in */  const char *scName,
                 /* in */  const char *name,
@@ -132,6 +133,10 @@ bool matchArguments(ArgumentList *,ArgumentList *,
                            const char *cl=0,const char *ns=0,bool checkCV=TRUE,
                            NamespaceSDict *usingNamespaces=0,
                            SDict<Definition> *usingClasses=0);
+bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
+                     Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
+                     bool checkCV
+                    );
 void mergeArguments(ArgumentList *,ArgumentList *,bool forceNameOverwrite=FALSE);
 QCString substituteClassNames(const QCString &s);
 QCString substitute(const char *s,const char *src,const char *dst);
@@ -175,7 +180,7 @@ QCString stripScope(const char *name);
 int iSystem(const char *command,const char *args,bool isBatchFile=FALSE);
 QCString convertToHtml(const char *s);
 QCString convertToXML(const char *s);
-const char * getOverloadDocs();
+QCString getOverloadDocs();
 void addMembersToMemberGroup(MemberList *ml,
                              MemberGroupSDict *memberGroupSDict,
                              Definition *context);
@@ -189,7 +194,8 @@ QCString substituteTemplateArgumentsInString(
 ArgumentList *copyArgumentList(const ArgumentList *src);
 QList<ArgumentList> *copyArgumentLists(const QList<ArgumentList> *srcLists);
 QCString stripTemplateSpecifiersFromScope(const QCString &fullName,
-                                          bool parentOnly=TRUE);
+                                          bool parentOnly=TRUE,
+                                          QCString *lastScopeStripped=0);
 QCString resolveTypeDef(Definition *d,const QCString &name,
                         Definition **typedefContext=0);
 QCString mergeScopes(const QCString &leftScope,const QCString &rightScope);
@@ -222,6 +228,8 @@ QCString relativePathToRoot(const char *name);
 #define REL_PATH_TO_ROOT "../../"
 void createSubDirs(QDir &d);
 QCString stripPath(const char *s);
+bool containsWord(const QCString &s,const QCString &word);
+bool findAndRemoveWord(QCString &s,const QCString &word);
 
 #endif
 
