@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -125,25 +125,25 @@ void XmlDocVisitor::visit(DocStyleChange *s)
   switch (s->style())
   {
     case DocStyleChange::Bold:
-      if (s->enable()) m_t << "<bold>";      else m_t << "</bold> ";
+      if (s->enable()) m_t << "<bold>";      else m_t << "</bold>";
       break;
     case DocStyleChange::Italic:
-      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis> ";
+      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis>";
       break;
     case DocStyleChange::Code:
-      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput> ";
+      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput>";
       break;
     case DocStyleChange::Subscript:
-      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript> ";
+      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript>";
       break;
     case DocStyleChange::Superscript:
-      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript> ";
+      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript>";
       break;
     case DocStyleChange::Center:
-      if (s->enable()) m_t << "<center>"; else m_t << "</center> ";
+      if (s->enable()) m_t << "<center>"; else m_t << "</center>";
       break;
     case DocStyleChange::Small:
-      if (s->enable()) m_t << "<small>";  else m_t << "</small> ";
+      if (s->enable()) m_t << "<small>";  else m_t << "</small>";
       break;
     case DocStyleChange::Preformatted:
       if (s->enable()) 
@@ -153,7 +153,7 @@ void XmlDocVisitor::visit(DocStyleChange *s)
       }
       else 
       {
-        m_t << "</preformatted> ";
+        m_t << "</preformatted>";
         m_insidePre=FALSE;
       }
       break;
@@ -641,6 +641,21 @@ void XmlDocVisitor::visitPre(DocImage *img)
     m_t << "\"";
   }
   m_t << ">";
+
+  // copy the image to the output dir
+  QFile inImage(img->name());
+  QFile outImage(Config_getString("XML_OUTPUT")+"/"+baseName.ascii());
+  if (inImage.open(IO_ReadOnly))
+  {
+    if (outImage.open(IO_WriteOnly))
+    {
+      char *buffer = new char[inImage.size()];
+      inImage.readBlock(buffer,inImage.size());
+      outImage.writeBlock(buffer,inImage.size());
+      outImage.flush();
+      delete buffer;
+    }
+  }
 }
 
 void XmlDocVisitor::visitPost(DocImage *) 
@@ -711,17 +726,17 @@ void XmlDocVisitor::visitPost(DocSecRefList *)
   m_t << "</toclist>" << endl;
 }
 
-void XmlDocVisitor::visitPre(DocLanguage *l)
-{
-  if (m_hide) return;
-  m_t << "<language langid=\"" << l->id() << "\">";
-}
-
-void XmlDocVisitor::visitPost(DocLanguage *) 
-{
-  if (m_hide) return;
-  m_t << "</language>" << endl;
-}
+//void XmlDocVisitor::visitPre(DocLanguage *l)
+//{
+//  if (m_hide) return;
+//  m_t << "<language langid=\"" << l->id() << "\">";
+//}
+//
+//void XmlDocVisitor::visitPost(DocLanguage *) 
+//{
+//  if (m_hide) return;
+//  m_t << "</language>" << endl;
+//}
 
 void XmlDocVisitor::visitPre(DocParamSect *s)
 {
@@ -750,9 +765,13 @@ void XmlDocVisitor::visitPost(DocParamSect *)
 void XmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
-  QStrListIterator li(pl->parameters());
-  const char *s;
-  for (li.toFirst();(s=li.current());++li)
+  m_t << "<parameteritem>" << endl;
+  m_t << "<parameternamelist>" << endl;
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
+  for (li.toFirst();(param=li.current());++li)
   {
     m_t << "<parametername";
     if (pl->direction()!=DocParamSect::Unspecified)
@@ -773,16 +792,25 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
       m_t << "\"";
     }
     m_t << ">";
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
     m_t << "</parametername>" << endl;
   }
+  m_t << "</parameternamelist>" << endl;
   m_t << "<parameterdescription>" << endl;
 }
 
 void XmlDocVisitor::visitPost(DocParamList *)
 {
   if (m_hide) return;
-  m_t << "</parameterdescription>";
+  m_t << "</parameterdescription>" << endl;
+  m_t << "</parameteritem>" << endl;
 }
 
 void XmlDocVisitor::visitPre(DocXRefItem *x)
