@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -478,6 +478,18 @@ static void writeMemberReference(QTextStream &t,Definition *def,MemberDef *rmd,c
   
 }
 
+static void stripQualifiers(QCString &typeStr)
+{
+  bool done=FALSE;
+  while (!done)
+  {
+    if (typeStr.left(7)=="static ") typeStr=typeStr.mid(7);
+    else if (typeStr.left(8)=="virtual ") typeStr=typeStr.mid(8);
+    else if (typeStr.left(9)=="volatile ") typeStr=typeStr.mid(9);
+    else done=TRUE;
+  }
+}
+
 static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,Definition *def)
 {
 
@@ -493,6 +505,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // - body code 
   // + template arguments 
   //     (templateArguments(), definitionTemplateParameterLists())
+  // - call graph
   
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
@@ -611,6 +624,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       writeMemberTemplateLists(md,t);
     }
     QCString typeStr = md->typeString(); //replaceAnonymousScopes(md->typeString());
+    stripQualifiers(typeStr);
     t << "        <type>";
     linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),typeStr);
     t << "</type>" << endl;
@@ -619,6 +633,15 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   }
 
   t << "        <name>" << convertToXML(md->name()) << "</name>" << endl;
+  
+  if (md->memberType() == MemberDef::Property)
+  {
+    if (md->isReadable())
+      t << "        <read>" << convertToXML(md->getReadAccessor()) << "</read>" << endl;
+    if (md->isWritable())
+      t << "        <write>" << convertToXML(md->getWriteAccessor()) << "</write>" << endl;
+  }
+  
   MemberDef *rmd = md->reimplements();
   if (rmd)
   {
@@ -709,7 +732,9 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       t << "        <param><defname>" << a->type << "</defname></param>" << endl;
     }
   }
-  if (!md->initializer().isEmpty())
+  // avoid that extremely large tables are written to the output. 
+  // todo: it's better to adhere to MAX_INITIALIZER_LINES.
+  if (!md->initializer().isEmpty() && md->initializer().length()<2000)
   {
     t << "        <initializer>";
     linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),md->initializer());
@@ -810,20 +835,42 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
 }
 
 static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
-                      MemberList *ml,const char *kind,const char *header=0)
+                      MemberList *ml,const char *kind,const char *header=0,
+                      const char *documentation=0)
 {
-  if (ml->count()==0) return; // empty list
+  MemberListIterator mli(*ml);
+  MemberDef *md;
+  int count=0;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      count++;
+    }
+  }
+  if (count==0) return; // empty list
 
   t << "      <sectiondef kind=\"" << kind << "\">" << endl;
   if (header)
   {
     t << "      <header>" << convertToXML(header) << "</header>" << endl;
   }
-  MemberListIterator mli(*ml);
-  MemberDef *md;
+  if (documentation)
+  {
+    t << "      <description>";
+    writeXMLDocBlock(t,d->docFile(),d->docLine(),d,0,documentation);
+    t << "</description>" << endl;
+  }
   for (mli.toFirst();(md=mli.current());++mli)
   {
-    generateXMLForMember(md,ti,t,d);
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      generateXMLForMember(md,ti,t,d);
+    }
   }
   t << "      </sectiondef>" << endl;
 }
@@ -870,6 +917,102 @@ static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
   t << "    </listofallmembers>" << endl;
 }
 
+static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
+{
+  if (cl)
+  {
+    ClassSDict::Iterator cli(*cl);
+    ClassDef *cd;
+    for (cli.toFirst();(cd=cli.current());++cli)
+    {
+      if (cd->name().find('@')==-1) // skip anonymous scopes
+      {
+        t << "    <innerclass refid=\"" << cd->getOutputFileBase()
+          << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
+      }
+    }
+  }
+}
+
+static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
+{
+  if (nl)
+  {
+    NamespaceSDict::Iterator nli(*nl);
+    NamespaceDef *nd;
+    for (nli.toFirst();(nd=nli.current());++nli)
+    {
+      if (nd->name().find('@')==-1) // skip anonymouse scopes
+      {
+        t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
+          << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
+      }
+    }
+  }
+}
+
+static void writeInnerFiles(const FileList *fl,QTextStream &t)
+{
+  if (fl)
+  {
+    QListIterator<FileDef> fli(*fl);
+    FileDef *fd;
+    for (fli.toFirst();(fd=fli.current());++fli)
+    {
+      t << "    <innerfile refid=\"" << fd->getOutputFileBase() 
+        << "\">" << convertToXML(fd->name()) << "</innerfile>" << endl;
+    }
+  }
+}
+
+static void writeInnerPages(const PageSDict *pl,QTextStream &t)
+{
+  if (pl)
+  {
+    PageSDict::Iterator pli(*pl);
+    PageDef *pd;
+    for (pli.toFirst();(pd=pli.current());++pli)
+    {
+      t << "    <innerpage refid=\"" << pd->getOutputFileBase();
+      if (pd->getGroupDef())
+      {
+        t << "_" << pd->name();
+      }
+      t << "\">" << convertToXML(pd->title()) << "</innerpage>" << endl;
+    }
+  }
+}
+
+static void writeInnerGroups(const GroupList *gl,QTextStream &t)
+{
+  if (gl)
+  {
+    GroupListIterator gli(*gl);
+    GroupDef *sgd;
+    for (gli.toFirst();(sgd=gli.current());++gli)
+    {
+      t << "    <innergroup refid=\"" << sgd->getOutputFileBase()
+        << "\">" << convertToXML(sgd->groupTitle()) 
+        << "</innergroup>" << endl;
+    }
+  }
+}
+
+static void writeInnerDirs(const DirList *dl,QTextStream &t)
+{
+  if (dl)
+  {
+    QListIterator<DirDef> subdirs(*dl);
+    DirDef *subdir;
+    for (subdirs.toFirst();(subdir=subdirs.current());++subdirs)
+    {
+      t << "    <innerdir refid=\"" << subdir->getOutputFileBase() 
+        << "\">" << convertToXML(subdir->displayName()) << "</innerdir>" << endl;
+    }
+  }
+}
+  
+
 static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
 {
   // + brief description
@@ -928,9 +1071,12 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     BaseClassDef *bcd;
     for (bcli.toFirst();(bcd=bcli.current());++bcli)
     {
-      t << "    <basecompoundref refid=\"" 
-        << bcd->classDef->getOutputFileBase()
-        << "\" prot=\"";
+      t << "    <basecompoundref ";
+      if (bcd->classDef->isLinkable())
+      {
+        t << "refid=\"" << bcd->classDef->getOutputFileBase() << "\" ";
+      }
+      t << "prot=\"";
       switch (bcd->prot)
       {
         case Public:    t << "public";    break;
@@ -945,8 +1091,19 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
         case Virtual: t << "virtual";      break;
         case Pure:    t <<"pure-virtual"; break;
       }
-      t << "\">" << convertToXML(bcd->classDef->displayName()) 
-        << "</basecompoundref>" << endl;
+      t << "\">";
+      if (!bcd->templSpecifiers.isEmpty())
+      {
+        convertToXML(
+            insertTemplateSpecifierInScope(
+              bcd->classDef->displayName(),bcd->templSpecifiers)
+           );
+      }
+      else
+      {
+        convertToXML(bcd->classDef->displayName());
+      }
+      t  << "</basecompoundref>" << endl;
     }
   }
   if (cd->subClasses()->count()>0)
@@ -995,25 +1152,15 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     }
   }
 
-  ClassSDict *cl = cd->getInnerClasses();
-  if (cl)
-  {
-    ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
-    for (cli.toFirst();(cd=cli.current());++cli)
-    {
-      t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-        << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
-    }
-  }
-
+  writeInnerClasses(cd->getInnerClasses(),t);
 
   writeTemplateList(cd,t);
   MemberGroupSDict::Iterator mgli(*cd->memberGroupSDict);
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
   {
-    generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header());
+    generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header(),
+                       mg->documentation());
   }
 
   generateXMLSection(cd,ti,t,&cd->pubTypes,"public-type");
@@ -1119,33 +1266,15 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
   writeXMLString(t,nd->name());
   t << "</compoundname>" << endl;
 
-  ClassSDict *cl = nd->classSDict;
-  if (cl)
-  {
-    ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
-    for (cli.toFirst();(cd=cli.current());++cli)
-    {
-      t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-        << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
-    }
-  }
-  NamespaceSDict *nl = nd->namespaceSDict;
-  if (nl)
-  {
-    NamespaceSDict::Iterator nli(*nl);
-    NamespaceDef *nd;
-    for (nli.toFirst();(nd=nli.current());++nli)
-    {
-      t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
-        << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
-    }
-  }
+  writeInnerClasses(nd->classSDict,t);
+  writeInnerNamespaces(nd->namespaceSDict,t);
+
   MemberGroupSDict::Iterator mgli(*nd->memberGroupSDict);
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
   {
-    generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header());
+    generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header(),
+                       mg->documentation());
   }
 
   generateXMLSection(nd,ti,t,&nd->decDefineMembers,"define");
@@ -1253,34 +1382,15 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     t << "    </invincdepgraph>" << endl;
   }
 
-  ClassSDict *cl = fd->classSDict;
-  if (cl)
-  {
-    ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
-    for (cli.toFirst();(cd=cli.current());++cli)
-    {
-      t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-        << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
-    }
-  }
-  NamespaceSDict *nl = fd->namespaceSDict;
-  if (nl)
-  {
-    NamespaceSDict::Iterator nli(*nl);
-    NamespaceDef *nd;
-    for (nli.toFirst();(nd=nli.current());++nli)
-    {
-      t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
-        << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
-    }
-  }
+  writeInnerClasses(fd->classSDict,t);
+  writeInnerNamespaces(fd->namespaceSDict,t);
 
   MemberGroupSDict::Iterator mgli(*fd->memberGroupSDict);
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
   {
-    generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header());
+    generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header(),
+                       mg->documentation());
   }
 
   generateXMLSection(fd,ti,t,&fd->decDefineMembers,"define");
@@ -1345,73 +1455,18 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   t << "    <compoundname>" << convertToXML(gd->name()) << "</compoundname>" << endl;
   t << "    <title>" << convertToXML(gd->groupTitle()) << "</title>" << endl;
 
-  FileList *fl = gd->getFiles();
-  if (fl)
-  {
-    QListIterator<FileDef> fli(*fl);
-    FileDef *fd = fl->first();
-    for (fli.toFirst();(fd=fli.current());++fli)
-    {
-      t << "    <innerfile refid=\"" << fd->getOutputFileBase() 
-        << "\">" << convertToXML(fd->name()) << "</innerfile>" << endl;
-    }
-  }
-  ClassSDict *cl = gd->getClasses();
-  if (cl)
-  {
-    ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
-    for (cli.toFirst();(cd=cli.current());++cli)
-    {
-      t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-        << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
-    }
-  }
-  NamespaceList *nl = gd->getNamespaces();
-  if (nl)
-  {
-    NamespaceListIterator nli(*nl);
-    NamespaceDef *nd;
-    for (nli.toFirst();(nd=nli.current());++nli)
-    {
-      t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
-        << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
-    }
-  }
-  PageSDict *pl = gd->getPages();
-  if (pl)
-  {
-    PageSDict::Iterator pli(*pl);
-    PageDef *pd;
-    for (pli.toFirst();(pd=pli.current());++pli)
-    {
-      t << "    <innerpage refid=\"" << pd->getOutputFileBase();
-      if (pd->getGroupDef())
-      {
-        t << "_" << pd->name();
-      }
-      t << "\">" << convertToXML(pd->title()) << "</innerpage>" << endl;
-    }
-  }
-
-  GroupList *gl = gd->getSubGroups();
-  if (gl)
-  {
-    GroupListIterator gli(*gl);
-    GroupDef *sgd;
-    for (gli.toFirst();(sgd=gli.current());++gli)
-    {
-      t << "    <innergroup refid=\"" << sgd->getOutputFileBase()
-        << "\">" << convertToXML(sgd->groupTitle()) 
-        << "</innergroup>" << endl;
-    }
-  }
+  writeInnerFiles(gd->getFiles(),t);
+  writeInnerClasses(gd->getClasses(),t);
+  writeInnerNamespaces(gd->getNamespaces(),t);
+  writeInnerPages(gd->getPages(),t);
+  writeInnerGroups(gd->getSubGroups(),t);
 
   MemberGroupSDict::Iterator mgli(*gd->memberGroupSDict);
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
   {
-    generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header());
+    generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header(),
+                       mg->documentation());
   }
 
   generateXMLSection(gd,ti,t,&gd->decDefineMembers,"define");
@@ -1433,6 +1488,45 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
+static void generateXMLForDir(DirDef *dd,QTextStream &ti)
+{
+  if (dd->isReference()) return; // skip external references
+  ti << "  <compound refid=\"" << dd->getOutputFileBase() 
+     << "\" kind=\"dir\"><name>" << convertToXML(dd->displayName()) 
+     << "</name>" << endl;
+
+  QCString outputDirectory = Config_getString("XML_OUTPUT");
+  QCString fileName=outputDirectory+"/"+dd->getOutputFileBase()+".xml";
+  QFile f(fileName);
+  if (!f.open(IO_WriteOnly))
+  {
+    err("Cannot open file %s for writing!\n",fileName.data());
+    return;
+  }
+
+  QTextStream t(&f);
+  t.setEncoding(QTextStream::Latin1);
+  writeXMLHeader(t);
+  t << "  <compounddef id=\"" 
+    << dd->getOutputFileBase() << "\" kind=\"dir\">" << endl;
+  t << "    <compoundname>" << convertToXML(dd->displayName()) << "</compoundname>" << endl;
+
+  writeInnerDirs(&dd->subDirs(),t);
+  writeInnerFiles(dd->getFiles(),t);
+
+  t << "    <briefdescription>" << endl;
+  writeXMLDocBlock(t,dd->briefFile(),dd->briefLine(),dd,0,dd->briefDescription());
+  t << "    </briefdescription>" << endl;
+  t << "    <detaileddescription>" << endl;
+  writeXMLDocBlock(t,dd->docFile(),dd->docLine(),dd,0,dd->documentation());
+  t << "    </detaileddescription>" << endl;
+  t << "    <location file=\"" << dd->name() << "\"/>" << endl; 
+  t << "  </compounddef>" << endl;
+  t << "</doxygen>" << endl;
+
+  ti << "  </compound>" << endl;
+}
+
 static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
 {
   // + name
@@ -1500,7 +1594,6 @@ void generateXML()
   // + classes
   // + namespaces
   // + files
-  // - packages
   // + groups
   // + related pages
   // - examples
@@ -1543,6 +1636,7 @@ void generateXML()
     }
   }
   QDir xmlDir(outputDirectory);
+  createSubDirs(xmlDir);
   QCString fileName=outputDirectory+"/index.xsd";
   QFile f(fileName);
   if (!f.open(IO_WriteOnly))
@@ -1580,13 +1674,24 @@ void generateXML()
   t << "xsi:noNamespaceSchemaLocation=\"index.xsd\" ";
   t << "version=\"" << versionString << "\">" << endl;
 
-  ClassSDict::Iterator cli(Doxygen::classSDict);
-  ClassDef *cd;
-  for (cli.toFirst();(cd=cli.current());++cli)
   {
-    msg("Generating XML output for class %s\n",cd->name().data());
-    generateXMLForClass(cd,t);
+    ClassSDict::Iterator cli(Doxygen::classSDict);
+    ClassDef *cd;
+    for (cli.toFirst();(cd=cli.current());++cli)
+    {
+      msg("Generating XML output for class %s\n",cd->name().data());
+      generateXMLForClass(cd,t);
+    }
   }
+  //{
+  //  ClassSDict::Iterator cli(Doxygen::hiddenClasses);
+  //  ClassDef *cd;
+  //  for (cli.toFirst();(cd=cli.current());++cli)
+  //  {
+  //    msg("Generating XML output for class %s\n",cd->name().data());
+  //    generateXMLForClass(cd,t);
+  //  }
+  //}
   NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
   NamespaceDef *nd;
   for (nli.toFirst();(nd=nli.current());++nli)
@@ -1622,6 +1727,15 @@ void generateXML()
       generateXMLForPage(pd,t,FALSE);
     }
   }
+  {
+    DirDef *dir;
+    DirSDict::Iterator sdi(Doxygen::directories);
+    for (sdi.toFirst();(dir=sdi.current());++sdi)
+    {
+      msg("Generate XML output for dir %s\n",dir->name().data());
+      generateXMLForDir(dir,t);
+    }
+  }
   {
     PageSDict::Iterator pdi(*Doxygen::exampleSDict);
     PageDef *pd=0;
